QueryAdmissionAccessKind

Enum QueryAdmissionAccessKind 

pub enum QueryAdmissionAccessKind {
    Unknown,
    ByKey,
    ByKeys,
    KeyRange,
    IndexPrefix,
    IndexMultiLookup,
    IndexBranchSet,
    IndexRange,
    FullScan,
    Union,
    Intersection,
}
Coarse selected access-path class used by admission and EXPLAIN.

Variants



Unknown

Access class has not been summarized yet.



ByKey

Direct primary-key lookup.



ByKeys

Multiple direct primary-key lookups.



KeyRange

Primary-key range access.



IndexPrefix

Secondary-index prefix access.



IndexMultiLookup

Secondary-index multi-lookup access.



IndexBranchSet

Secondary-index branch-set access.



IndexRange

Secondary-index range access.



FullScan

Full entity scan.



Union

Union of multiple access paths.



Intersection

Intersection of multiple access paths.

Implementations

Source

impl QueryAdmissionAccessKind

pub const fn as_str(self) -> &'static str

Return a stable lowercase diagnostic label for this access class.

pub const fn is_secondary_index(self) -> bool

Return whether this access class is backed by a secondary index.

pub const fn is_full_scan(self) -> bool

Return whether this access class is a full entity scan.