pub enum ReadPlanCacheOutcome {
Hit,
Miss,
Bypassed,
}Expand description
Shared plan-cache outcome for the selected read plan.
Variants
Hit
The selected prepared plan was reused.
Miss
The selected prepared plan was built for this call.
Bypassed
The selected path did not report a cache lookup outcome.