pub enum SchemaChangeProgressStatus {
Started,
Advanced {
phase: SchemaChangeValidationPhase,
rows_scanned: u64,
},
Findings {
phase: SchemaChangeValidationPhase,
rows_scanned: u64,
page_sequence: u64,
findings: Vec<ConstraintDiagnostic>,
},
Restarted {
rows_scanned: u64,
},
Applied,
Aborted,
}Expand description
SchemaChangeProgressStatus
Result of one bounded schema-change continuation call.
Variants
Started
The durable 0.211 validation job was created.
Advanced
One clean bounded page advanced.
Fields

phase: SchemaChangeValidationPhaseCurrent canonical proof phase.
Findings
One bounded finding page remains retained until acknowledged.
Fields

phase: SchemaChangeValidationPhaseCurrent canonical proof phase.

findings: Vec<ConstraintDiagnostic>Bounded accepted-constraint diagnostics for this page.
Restarted
Verify authority drifted and the canonical proof restarted at Forward.
Applied
Every activation completed and the durable receipt became terminal.
Aborted
The authorized owner aborted the pending activation.