pub enum SchemaMigrationExecutionOutcome {
AlreadyApplied,
Executed(MigrationRunOutcome),
}Expand description
SchemaMigrationExecutionOutcome
SchemaMigrationExecutionOutcome reports whether schema evolution skipped an
already-applied migration or delegated a planned migration to db::migration.
The lower migration outcome is preserved unchanged when execution occurs.
Variants
AlreadyApplied
Executed(MigrationRunOutcome)
Implementations
Sourceimpl SchemaMigrationExecutionOutcome
impl SchemaMigrationExecutionOutcome
Sourcepub const fn already_applied(self) -> bool
pub const fn already_applied(self) -> bool
Return whether schema evolution skipped execution because the registry already contains this migration id/version.
Sourcepub const fn migration_outcome(self) -> Option<MigrationRunOutcome>
pub const fn migration_outcome(self) -> Option<MigrationRunOutcome>
Return the lower migration-run outcome when execution occurred.