pub enum StoreRecoveryCapability {
StableCommitReplay,
StableBasePlusJournalReplay,
None,
}Expand description
Store recovery capability.
Variants
StableCommitReplay
Store contents can be recovered through stable commit replay.
StableBasePlusJournalReplay
Store contents can be recovered from canonical stable BTrees plus a committed journal tail.
None
Store contents are not recovered.
Implementations