pub enum StoreRelationTargetCapability {
DurableTarget,
VolatileTarget,
}Expand description
Strong relation target capability for a store.
Variants
DurableTarget
Target rows can be referenced by durable source rows.
VolatileTarget
Target rows are volatile and cannot satisfy durable source integrity.