pub fn begin_commit(marker: CommitMarker) -> Result<CommitGuard, InternalError>Expand description
Persist a commit marker and open the commit window.
pub fn begin_commit(marker: CommitMarker) -> Result<CommitGuard, InternalError>Persist a commit marker and open the commit window.