FieldPresence

Enum FieldPresence 

pub enum FieldPresence {
    Present(Value),
    Missing,
}
FieldPresence

Result of attempting to read a field from a row during predicate evaluation. This distinguishes between a missing field and a present field whose value may be None.

Variants



Present(Value)

Field exists and has a value (including Value::None).



Missing

Field is not present on the row.