pub struct AccessRequirementError { /* private fields */ }Expand description
Query access requirement failure with the selected decision preserved.
Implementations
Sourceimpl AccessRequirementError
impl AccessRequirementError
Sourcepub const fn violation(&self) -> &AccessRequirementViolation
pub const fn violation(&self) -> &AccessRequirementViolation
Borrow the violated access requirement.
Sourcepub const fn decision(&self) -> &ExplainAccessDecisionV1
pub const fn decision(&self) -> &ExplainAccessDecisionV1
Borrow the selected access decision that failed the requirement.