pub struct EntitySchemaDescription { /* private fields */ }Expand description
EntitySchemaDescription
Stable describe payload for one entity model.
Implementations
Sourceimpl EntitySchemaDescription
impl EntitySchemaDescription
Sourcepub const fn new(
entity_path: String,
entity_name: String,
entity_tag: u64,
accepted_schema_fingerprint_method: u8,
accepted_schema_fingerprint: [u8; 16],
primary_key: String,
primary_key_fields: Vec<String>,
fields: Vec<EntityFieldDescription>,
indexes: Vec<EntityIndexDescription>,
relations: Vec<EntityRelationDescription>,
constraints: Vec<EntityConstraintDescription>,
row_layout_current: u32,
row_layout_history_floor: u32,
) -> Self
pub const fn new( entity_path: String, entity_name: String, entity_tag: u64, accepted_schema_fingerprint_method: u8, accepted_schema_fingerprint: [u8; 16], primary_key: String, primary_key_fields: Vec<String>, fields: Vec<EntityFieldDescription>, indexes: Vec<EntityIndexDescription>, relations: Vec<EntityRelationDescription>, constraints: Vec<EntityConstraintDescription>, row_layout_current: u32, row_layout_history_floor: u32, ) -> Self
Construct one entity schema description payload.
Sourcepub const fn entity_path(&self) -> &str
pub const fn entity_path(&self) -> &str
Borrow the entity module path.
Sourcepub const fn entity_name(&self) -> &str
pub const fn entity_name(&self) -> &str
Borrow the entity display name.
Sourcepub const fn entity_tag(&self) -> u64
pub const fn entity_tag(&self) -> u64
Return the accepted durable entity identity used by diagnostic facts.
Sourcepub const fn accepted_schema_fingerprint_method(&self) -> u8
pub const fn accepted_schema_fingerprint_method(&self) -> u8
Return the accepted schema-fingerprint method used by diagnostic facts.
Sourcepub const fn accepted_schema_fingerprint(&self) -> [u8; 16]
pub const fn accepted_schema_fingerprint(&self) -> [u8; 16]
Return the exact accepted entity-schema fingerprint.
Sourcepub const fn primary_key(&self) -> &str
pub const fn primary_key(&self) -> &str
Borrow the rendered primary-key field list.
Sourcepub const fn primary_key_fields(&self) -> &[String]
pub const fn primary_key_fields(&self) -> &[String]
Borrow ordered primary-key field names.
Sourcepub fn identity(&self) -> Option<&EntityIdentityDescription>
pub fn identity(&self) -> Option<&EntityIdentityDescription>
Borrow the accepted Identity policy and lifetime allocation state.
Sourcepub const fn fields(&self) -> &[EntityFieldDescription]
pub const fn fields(&self) -> &[EntityFieldDescription]
Borrow field description entries.
Sourcepub const fn indexes(&self) -> &[EntityIndexDescription]
pub const fn indexes(&self) -> &[EntityIndexDescription]
Borrow index description entries.
Sourcepub const fn relations(&self) -> &[EntityRelationDescription]
pub const fn relations(&self) -> &[EntityRelationDescription]
Borrow relation description entries.
Sourcepub const fn constraints(&self) -> &[EntityConstraintDescription]
pub const fn constraints(&self) -> &[EntityConstraintDescription]
Borrow accepted or generated structural constraint descriptions.
Sourcepub const fn row_layout_current(&self) -> u32
pub const fn row_layout_current(&self) -> u32
Return the current accepted physical row-layout identity.
Sourcepub const fn row_layout_history_floor(&self) -> u32
pub const fn row_layout_history_floor(&self) -> u32
Return the oldest admitted physical row-layout identity.