ExplainRejectedIndexV1

Struct ExplainRejectedIndexV1 

pub struct ExplainRejectedIndexV1 {
    pub index_name: Option<String>,
    pub reason: Option<String>,
    pub label: String,
}
Rejected index candidate summary recorded by the planner.

Fields

index_name: Option<String>

Semantic index name when parsed from the planner rejection label.

reason: Option<String>

Planner-owned rejection reason code when parsed from the rejection label.

label: String

Original planner rejection label.