pub struct ExplainResidualSummary {
pub burden_class: &'static str,
pub has_residual_filter: bool,
pub has_residual_predicate: bool,
pub access_bound_predicate_count: usize,
pub residual_predicate_count: usize,
}Expand description
Residual-work summary for the selected access route.
Fields
burden_class: &'static strResidual burden class for the selected access route.
has_residual_filter: boolWhether any residual scalar filter expression survives access planning.
has_residual_predicate: boolWhether any residual predicate model survives access planning.
access_bound_predicate_count: usizeNumber of predicate-like constraints structurally consumed by access.
residual_predicate_count: usizeNumber of residual predicate terms for the selected access route.