IntegrityFinding

Struct IntegrityFinding 

pub struct IntegrityFinding { /* private fields */ }
One bounded machine-readable integrity finding.

Raw row payloads and unbounded application values are deliberately absent.

Implementations

Source

impl IntegrityFinding

pub const fn diagnostic_code(&self) -> u16

Return the stable compact diagnostic code.

pub const fn class(&self) -> IntegrityFindingClass

Return the broad finding class.

pub const fn severity(&self) -> IntegritySeverity

Return the finding severity.

pub const fn kind(&self) -> IntegrityFindingKind

Return the stable semantic finding family.

pub const fn entity(&self) -> &IntegrityEntityIdentity

Borrow the accepted entity identity.

pub const fn store_path(&self) -> &str

Borrow the affected store path.

pub const fn phase(&self) -> IntegrityPhase

Return the Deep phase that observed this finding.

pub const fn verifier_family(&self) -> IntegrityVerifierFamily

Return the deterministic verifier family that observed this finding.

pub const fn physical_key(&self) -> &[u8]

Borrow the bounded exact physical key.

pub fn primary_key(&self) -> Option<&[u8]>

Borrow the canonical primary-key suffix after successful key decoding.

pub const fn field_paths(&self) -> &[String]

Borrow bounded accepted field paths relevant to the finding.

pub const fn constraint_id(&self) -> Option<u32>

Return the accepted constraint identity when applicable.

pub fn constraint_name(&self) -> Option<&str>

Borrow the accepted constraint name when applicable.

pub const fn schema_index_id(&self) -> Option<u32>

Return the accepted logical index identity when applicable.

pub const fn relation_id(&self) -> Option<u32>

Return the accepted relation identity when applicable.

pub fn expected(&self) -> Option<&str>

Borrow the bounded expected-state label, when applicable.

pub fn observed(&self) -> Option<&str>

Borrow the bounded observed-state label, when applicable.