pub struct MigrationCursor { /* private fields */ }Expand description
MigrationCursor
Explicit migration resume cursor. This cursor tracks the next step index to execute in one migration plan. The migration runtime persists this cursor durably between executions.
Implementations