pub struct MigrationRegistry { /* private fields */ }Expand description
MigrationRegistry
MigrationRegistry tracks schema migrations that have completed above the
lower db::migration execution engine.
This first implementation is an explicit owner object so no commit/storage
layout changes are required by the schema-evolution slice.
Implementations
Sourceimpl MigrationRegistry
impl MigrationRegistry
Sourcepub fn is_applied(&self, migration_id: EntityName, version: u64) -> bool
pub fn is_applied(&self, migration_id: EntityName, version: u64) -> bool
Return whether the migration id/version is already recorded as complete.
Sourcepub fn record_applied(&mut self, migration_id: EntityName, version: u64)
pub fn record_applied(&mut self, migration_id: EntityName, version: u64)
Record one migration id/version as complete.