QueryAdmissionSummary

Struct QueryAdmissionSummary 

pub struct QueryAdmissionSummary { /* private fields */ }
Read-admission result and plan facts for diagnostics and EXPLAIN.

Implementations

Source

impl QueryAdmissionSummary

pub const fn admitted( lane: QueryAdmissionLane, selected_access: QueryAdmissionAccessKind, ) -> Self

Build an admitted summary with unknown bound details.

pub const fn rejected( lane: QueryAdmissionLane, selected_access: QueryAdmissionAccessKind, rejection: QueryAdmissionRejection, ) -> Self

Build a rejected summary with unknown bound details.

pub const fn lane(&self) -> QueryAdmissionLane

Return the admission lane.

pub const fn decision(&self) -> QueryAdmissionDecision

Return the final decision.

pub const fn plan_shape(&self) -> QueryAdmissionPlanShape

Return the scalar/grouped statement shape.

pub const fn selected_access(&self) -> QueryAdmissionAccessKind

Return the selected access class.

pub fn selected_index(&self) -> Option<&str>

Return the selected index name, if one exists.

pub const fn limit(&self) -> Option<u32>

Return the caller-visible LIMIT, if present.

pub const fn offset(&self) -> Option<u32>

Return the caller-visible OFFSET, if present.

pub const fn scan_bound(&self) -> Option<u64>

Return the scan bound, if known.

pub const fn scan_bound_kind(&self) -> QueryBoundKind

Return the quality of the scan bound.

pub const fn returned_row_bound(&self) -> Option<u32>

Return the returned-row bound, if known.

pub const fn returned_row_bound_kind(&self) -> QueryBoundKind

Return the quality of the returned-row bound.

pub const fn response_byte_bound(&self) -> Option<u32>

Return the response-byte bound, if known.

pub const fn response_byte_bound_kind(&self) -> QueryBoundKind

Return the quality of the response-byte bound.

pub const fn residual_filter(&self) -> QueryAdmissionResidualFilter

Return post-access residual filter facts.

pub const fn ordering(&self) -> QueryAdmissionOrdering

Return ORDER BY facts.

pub const fn grouped(&self) -> Option<QueryAdmissionGroupedSummary>

Return grouped query facts, if this is a grouped plan.

pub const fn materialization(&self) -> QueryMaterializationSummary

Return materialization facts.

pub const fn rejection(&self) -> Option<QueryAdmissionRejection>

Return the rejection reason, when the decision is rejected.