RowResponse

Struct RowResponse 

pub struct RowResponse<R: ResponseRow>(/* private fields */);
Response

Generic response transport container for one row shape R.

Implementations

Source

impl<R: ResponseRow> Response<R>

pub const fn new(rows: Vec<R>) -> Self

Construct one response from ordered rows.

pub const fn len(&self) -> usize

Return the number of rows.

pub const fn count(&self) -> u32

Return the number of rows as a u32 API contract count.

pub const fn is_empty(&self) -> bool

Return whether this response has no rows.

pub fn rows(self) -> Vec<R>

Consume and return all rows in response order.

pub const fn as_slice(&self) -> &[R]

Borrow rows as a slice in response order.

pub fn iter(&self) -> Iter<'_, R>

Borrow an iterator over rows in response order.

Source

impl<E: EntityKind> Response<Row<E>>

pub fn entities(self) -> Vec<E>

Consume and return all entities in response order.

pub fn ids(&self) -> impl Iterator<Item = Id<E>> + '_

Borrow an iterator over row identifiers in response order.

pub fn contains_id(&self, id: &Id<E>) -> bool

Check whether the response contains the provided identifier.