pub struct StoreAllocationIdentities { /* private fields */ }Expand description
StoreAllocationIdentities
Durable allocation identities for one logical store’s data, index, and schema memories.
Implementations
Sourceimpl StoreAllocationIdentities
impl StoreAllocationIdentities
Sourcepub const fn new(
data: StoreAllocationIdentity,
index: StoreAllocationIdentity,
schema: StoreAllocationIdentity,
) -> Self
pub const fn new( data: StoreAllocationIdentity, index: StoreAllocationIdentity, schema: StoreAllocationIdentity, ) -> Self
Build one allocation identity bundle.
Sourcepub const fn new_journaled(
data: StoreAllocationIdentity,
index: StoreAllocationIdentity,
schema: StoreAllocationIdentity,
journal: StoreAllocationIdentity,
) -> Self
pub const fn new_journaled( data: StoreAllocationIdentity, index: StoreAllocationIdentity, schema: StoreAllocationIdentity, journal: StoreAllocationIdentity, ) -> Self
Build one journaled cached-stable allocation identity bundle.
Sourcepub const fn data(self) -> Option<StoreAllocationIdentity>
pub const fn data(self) -> Option<StoreAllocationIdentity>
Return data-memory allocation identity.
Sourcepub const fn index(self) -> Option<StoreAllocationIdentity>
pub const fn index(self) -> Option<StoreAllocationIdentity>
Return index-memory allocation identity.
Sourcepub const fn schema(self) -> Option<StoreAllocationIdentity>
pub const fn schema(self) -> Option<StoreAllocationIdentity>
Return schema-memory allocation identity.
Sourcepub const fn journal(self) -> Option<StoreAllocationIdentity>
pub const fn journal(self) -> Option<StoreAllocationIdentity>
Return journal-tail allocation identity.
Sourcepub const fn allocation_identity_capability(
self,
) -> Option<StoreAllocationIdentityCapability>
pub const fn allocation_identity_capability( self, ) -> Option<StoreAllocationIdentityCapability>
Return the allocation capability represented by this triplet, or
None if the triplet is partially populated and therefore invalid.
Sourcepub const fn matches_storage_capabilities(
self,
capabilities: StoreRuntimeStorageCapabilities,
) -> bool
pub const fn matches_storage_capabilities( self, capabilities: StoreRuntimeStorageCapabilities, ) -> bool
Return whether this allocation shape matches the concrete storage capability descriptor.