WriteBatchResponse

Struct WriteBatchResponse 

pub struct WriteBatchResponse<E> { /* private fields */ }
WriteBatchResponse

Result of a batch write operation. Provides explicit access to stored entities and their identifiers.

Implementations

Source

impl<E> WriteBatchResponse<E>

pub fn new(entities: Vec<E>) -> Self

Construct a batch response from stored entities.

pub fn entries(&self) -> &[WriteResponse<E>]

Return all write responses.

pub const fn len(&self) -> usize

Return the number of entries.

pub const fn is_empty(&self) -> bool

Returns true if the batch is empty.

pub fn entities(self) -> Vec<E>

Return all stored entities.

pub fn ids(&self) -> Vec<Id<E>>
where E: EntityValue,

Return all primary keys for correlation, reporting, and lookup.

pub fn views(&self) -> Vec<<E as AsView>::ViewType>
where E: AsView,

Return all views.

Source

impl<E> WriteBatchResponse<E>

pub fn iter(&self) -> Iter<'_, WriteResponse<E>>