FromKey

Trait FromKey 

pub trait FromKey: Copy {
    // Required method
    fn try_from_key(key: Key) -> Option<Self>;
}
FromKey Convert a stored Key into a concrete type. Returns None if the key cannot represent this type.

Required Methods

fn try_from_key(key: Key) -> Option<Self>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromKey for i8

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for i16

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for i32

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for i64

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for u8

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for u16

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for u32

Source

fn try_from_key(key: Key) -> Option<Self>

Source

impl FromKey for u64

Source

fn try_from_key(key: Key) -> Option<Self>

Implementors

Source

impl FromKey for Account

Account

Source

impl FromKey for Principal

Principal

Source

impl FromKey for Subaccount

Subaccount

Source

impl FromKey for Timestamp

Timestamp

Source

impl FromKey for Ulid

Ulid

Source

impl FromKey for Unit

Unit