EntityKind

Trait EntityKind 

pub trait EntityKind:
    EntityDeclaration
    + EntityPlacement
    + TypeKind {
    const ENTITY_TAG: EntityTag;
}
Declaration- and placement-bound entity model.

This contract is sufficient for proposal-based, model-only planning and does not imply that Self is a materializable entity value. Stored runtime entities prove that additional capability through PersistedRow.

Required Associated Constants

const ENTITY_TAG: EntityTag

Stable compact entity identity used by runtime routing.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors