pub enum QueryErrorDetail {
NumericOverflow,
NumericNotRepresentable,
UnsupportedSqlFeature {
feature: SqlFeatureCode,
},
SqlLowering {
reason: SqlLoweringCode,
},
UnsupportedProjection {
reason: QueryProjectionCode,
},
UnknownAggregateTargetField,
ResultShapeMismatch {
reason: QueryResultShapeCode,
},
SqlSurfaceMismatch {
mismatch: SqlSurfaceMismatchCode,
},
SqlWriteBoundary {
boundary: SqlWriteBoundaryCode,
},
SchemaDdlAdmission {
error: SchemaDdlAdmissionError,
},
}Expand description
QueryErrorDetail
Query-origin structured error detail payload.
Variants
NumericOverflow
NumericNotRepresentable
UnsupportedSqlFeature
Fields

feature: SqlFeatureCodeSqlLowering
Fields

reason: SqlLoweringCodeUnsupportedProjection
Fields

reason: QueryProjectionCodeUnknownAggregateTargetField
ResultShapeMismatch
Fields

reason: QueryResultShapeCodeSqlSurfaceMismatch
Fields

mismatch: SqlSurfaceMismatchCodeSqlWriteBoundary
Fields

boundary: SqlWriteBoundaryCodeSchemaDdlAdmission
Fields

error: SchemaDdlAdmissionErrorImplementations
Sourceimpl QueryErrorDetail
impl QueryErrorDetail
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this query detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail when the query detail has one.