pub enum RecoveryErrorDetail {
UnsupportedFormatVersion {
found: Option<u16>,
required: u16,
},
MalformedFormatMarker {
reason: RecoveryFormatMarkerError,
},
}Expand description
RecoveryErrorDetail
Recovery-origin structured error detail payload.
Variants
Implementations
Sourceimpl RecoveryErrorDetail
impl RecoveryErrorDetail
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this recovery detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail for this recovery detail.