pub enum SerializeErrorDetail {
PersistedRowLayoutOutsideAcceptedWindow,
PersistedRowSlotCountMismatch,
}Expand description
Persisted-row serialization and decoding error detail.
Variants
PersistedRowLayoutOutsideAcceptedWindow
The row stamp is older or newer than the accepted layout window.
PersistedRowSlotCountMismatch
The physical slot count does not match the row’s stamped layout.
Implementations
Sourceimpl SerializeErrorDetail
impl SerializeErrorDetail
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this serialization detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail for this serialization detail.