pub enum StoreError {
NotFound {
key: String,
},
Corrupt {
message: String,
},
InvariantViolation {
message: String,
},
SchemaDdlPublicationRaceLost {
entity_path: String,
},
SchemaDdlSetNotNullValidationFailed {
entity_path: String,
column_name: String,
},
}Expand description
StoreError
Store-specific structured error detail.
Never returned directly; always wrapped in ErrorDetail::Store.
Variants
NotFound
Corrupt
InvariantViolation
SchemaDdlPublicationRaceLost
SchemaDdlSetNotNullValidationFailed
Implementations
Sourceimpl StoreError
impl StoreError
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this store detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail when the store error has one.