pub enum PlanChoiceReason {
Show 14 variants
ConflictingPrimaryKeyChildrenAccessPreferred,
ConstantFalsePredicate,
EmptyChildAccessPreferred,
FullScanAccess,
IntentKeyAccessOverride,
LimitZeroWindow,
NonIndexAccess,
PlannerCompositeNonIndex,
PlannerFullScanFallback,
PlannerKeySetAccess,
PlannerPrimaryKeyLookup,
PlannerPrimaryKeyRange,
RequiredOrderPrimaryKeyRangePreferred,
SingletonPrimaryKeyChildAccessPreferred,
}Expand description
PlanChoiceReason
Stable selected-route reason buckets for non-index and primary-key access choices. These counters explain why a query did not land on a secondary index route without exposing predicates, literals, or index names.
Variants
ConflictingPrimaryKeyChildrenAccessPreferred
ConstantFalsePredicate
EmptyChildAccessPreferred
FullScanAccess
IntentKeyAccessOverride
LimitZeroWindow
NonIndexAccess
PlannerCompositeNonIndex
PlannerFullScanFallback
PlannerKeySetAccess
PlannerPrimaryKeyLookup
PlannerPrimaryKeyRange
RequiredOrderPrimaryKeyRangePreferred
SingletonPrimaryKeyChildAccessPreferred