pub enum SchemaTransitionOutcome {
AppendOnlyNullableFields,
ExactMatch,
RejectedEntityIdentity,
RejectedFieldContract,
RejectedFieldSlot,
RejectedRowLayout,
RejectedSchemaVersion,
RejectedSnapshot,
}Expand description
SchemaTransitionOutcome
Stable schema transition policy buckets. These counters isolate the policy decision for an existing accepted snapshot from broader reconciliation outcomes such as first-create writes, corrupt stores, or store failures.
Variants
AppendOnlyNullableFields
ExactMatch
RejectedEntityIdentity
RejectedFieldContract
RejectedFieldSlot
RejectedRowLayout
RejectedSchemaVersion
RejectedSnapshot