pub struct CompactMetricsReport { /* private fields */ }Expand description
CompactMetricsReport
Compact metrics query payload.
Implementations
Sourceimpl CompactMetricsReport
impl CompactMetricsReport
Sourcepub const fn counters(&self) -> Option<&CompactEventCounters>
pub const fn counters(&self) -> Option<&CompactEventCounters>
Borrow the compact global counters when the requested window matched.
Sourcepub fn entity_counters(&self) -> &[CompactEntityMetrics]
pub fn entity_counters(&self) -> &[CompactEntityMetrics]
Borrow compact per-entity counters.
Sourcepub const fn window_filter_matched(&self) -> bool
pub const fn window_filter_matched(&self) -> bool
Return whether the requested window matched the active window.
Sourcepub const fn requested_window_start_ms(&self) -> Option<u64>
pub const fn requested_window_start_ms(&self) -> Option<u64>
Return the requested window start timestamp, if supplied.
Sourcepub const fn active_window_start_ms(&self) -> u64
pub const fn active_window_start_ms(&self) -> u64
Return the active metrics window start timestamp.