pub struct EntitySummary { /* private fields */ }Expand description
EntitySummary
Per-entity metrics summary.
Implementations
Sourceimpl EntitySummary
impl EntitySummary
pub const fn path(&self) -> &str
pub const fn load_calls(&self) -> u64
pub const fn save_calls(&self) -> u64
pub const fn delete_calls(&self) -> u64
pub const fn save_insert_calls(&self) -> u64
pub const fn save_update_calls(&self) -> u64
pub const fn save_replace_calls(&self) -> u64
pub const fn exec_success(&self) -> u64
pub const fn exec_error_corruption(&self) -> u64
pub const fn exec_error_incompatible_persisted_format(&self) -> u64
pub const fn exec_error_not_found(&self) -> u64
pub const fn exec_error_internal(&self) -> u64
pub const fn exec_error_conflict(&self) -> u64
pub const fn exec_error_unsupported(&self) -> u64
pub const fn exec_error_invariant_violation(&self) -> u64
pub const fn exec_aborted(&self) -> u64
pub const fn cache_sql_compiled_command_hits(&self) -> u64
pub const fn cache_sql_compiled_command_misses(&self) -> u64
pub const fn cache_sql_compiled_command_inserts(&self) -> u64
pub const fn cache_sql_compiled_command_miss_cold(&self) -> u64
pub const fn cache_sql_compiled_command_miss_distinct_key(&self) -> u64
pub const fn cache_sql_compiled_command_miss_method_version(&self) -> u64
pub const fn cache_sql_compiled_command_miss_schema_fingerprint(&self) -> u64
pub const fn cache_sql_compiled_command_miss_surface(&self) -> u64
pub const fn schema_reconcile_checks(&self) -> u64
pub const fn schema_reconcile_exact_match(&self) -> u64
pub const fn schema_reconcile_first_create(&self) -> u64
pub const fn schema_reconcile_latest_snapshot_corrupt(&self) -> u64
pub const fn schema_reconcile_rejected_field_slot(&self) -> u64
pub const fn schema_reconcile_rejected_other(&self) -> u64
pub const fn schema_reconcile_rejected_row_layout(&self) -> u64
pub const fn schema_reconcile_rejected_schema_version(&self) -> u64
pub const fn schema_reconcile_store_write_error(&self) -> u64
pub const fn schema_transition_checks(&self) -> u64
pub const fn schema_transition_append_only_nullable_fields(&self) -> u64
pub const fn schema_transition_exact_match(&self) -> u64
pub const fn schema_transition_rejected_entity_identity(&self) -> u64
pub const fn schema_transition_rejected_field_contract(&self) -> u64
pub const fn schema_transition_rejected_field_slot(&self) -> u64
pub const fn schema_transition_rejected_row_layout(&self) -> u64
pub const fn schema_transition_rejected_schema_version(&self) -> u64
pub const fn schema_transition_rejected_snapshot(&self) -> u64
pub const fn schema_store_snapshots(&self) -> u64
pub const fn schema_store_encoded_bytes(&self) -> u64
pub const fn schema_store_latest_snapshot_bytes(&self) -> u64
pub const fn accepted_schema_fields(&self) -> u64
pub const fn accepted_schema_nested_leaf_facts(&self) -> u64
pub const fn sql_compile_rejects(&self) -> u64
pub const fn sql_compile_reject_cache_key(&self) -> u64
pub const fn sql_compile_reject_parse(&self) -> u64
pub const fn sql_compile_reject_semantic(&self) -> u64
pub const fn plan_index(&self) -> u64
pub const fn plan_keys(&self) -> u64
pub const fn plan_range(&self) -> u64
pub const fn plan_full_scan(&self) -> u64
pub const fn plan_by_key(&self) -> u64
pub const fn plan_by_keys(&self) -> u64
pub const fn plan_key_range(&self) -> u64
pub const fn plan_index_prefix(&self) -> u64
pub const fn plan_index_multi_lookup(&self) -> u64
pub const fn plan_index_range(&self) -> u64
pub const fn plan_explicit_full_scan(&self) -> u64
pub const fn plan_union(&self) -> u64
pub const fn plan_intersection(&self) -> u64
pub const fn plan_grouped_hash_materialized(&self) -> u64
pub const fn plan_grouped_ordered_materialized(&self) -> u64
pub const fn plan_choice_conflicting_primary_key_children_access_preferred( &self, ) -> u64
pub const fn plan_choice_constant_false_predicate(&self) -> u64
pub const fn plan_choice_empty_child_access_preferred(&self) -> u64
pub const fn plan_choice_full_scan_access(&self) -> u64
pub const fn plan_choice_intent_key_access_override(&self) -> u64
pub const fn plan_choice_limit_zero_window(&self) -> u64
pub const fn plan_choice_non_index_access(&self) -> u64
pub const fn plan_choice_planner_composite_non_index(&self) -> u64
pub const fn plan_choice_planner_full_scan_fallback(&self) -> u64
pub const fn plan_choice_planner_key_set_access(&self) -> u64
pub const fn plan_choice_planner_primary_key_lookup(&self) -> u64
pub const fn plan_choice_planner_primary_key_range(&self) -> u64
pub const fn plan_choice_required_order_primary_key_range_preferred( &self, ) -> u64
pub const fn plan_choice_singleton_primary_key_child_access_preferred( &self, ) -> u64
pub const fn prepared_shape_already_finalized(&self) -> u64
pub const fn prepared_shape_generated_fallback(&self) -> u64
pub const fn rows_loaded(&self) -> u64
pub const fn rows_saved(&self) -> u64
pub const fn rows_inserted(&self) -> u64
pub const fn rows_updated(&self) -> u64
pub const fn rows_replaced(&self) -> u64
pub const fn rows_scanned(&self) -> u64
pub const fn rows_filtered(&self) -> u64
pub const fn rows_aggregated(&self) -> u64
pub const fn rows_emitted(&self) -> u64
pub const fn load_candidate_rows_scanned(&self) -> u64
pub const fn load_candidate_rows_filtered(&self) -> u64
pub const fn load_result_rows_emitted(&self) -> u64
pub const fn rows_deleted(&self) -> u64
pub const fn sql_insert_calls(&self) -> u64
pub const fn sql_insert_select_calls(&self) -> u64
pub const fn sql_update_calls(&self) -> u64
pub const fn sql_delete_calls(&self) -> u64
pub const fn sql_write_matched_rows(&self) -> u64
pub const fn sql_write_mutated_rows(&self) -> u64
pub const fn sql_write_returning_rows(&self) -> u64
pub const fn sql_write_error_insert(&self) -> u64
pub const fn sql_write_error_insert_select(&self) -> u64
pub const fn sql_write_error_update(&self) -> u64
pub const fn sql_write_error_delete(&self) -> u64
pub const fn sql_write_error_corruption(&self) -> u64
pub const fn sql_write_error_incompatible_persisted_format(&self) -> u64
pub const fn sql_write_error_not_found(&self) -> u64
pub const fn sql_write_error_internal(&self) -> u64
pub const fn sql_write_error_conflict(&self) -> u64
pub const fn sql_write_error_unsupported(&self) -> u64
pub const fn sql_write_error_invariant_violation(&self) -> u64
pub const fn index_inserts(&self) -> u64
pub const fn index_removes(&self) -> u64
pub const fn reverse_index_inserts(&self) -> u64
pub const fn reverse_index_removes(&self) -> u64
pub const fn relation_reverse_lookups(&self) -> u64
pub const fn relation_delete_blocks(&self) -> u64
pub const fn write_rows_touched(&self) -> u64
pub const fn write_index_entries_changed(&self) -> u64
pub const fn write_reverse_index_entries_changed(&self) -> u64
pub const fn write_relation_checks(&self) -> u64
pub const fn unique_violations(&self) -> u64
pub const fn non_atomic_partial_commits(&self) -> u64
pub const fn non_atomic_partial_rows_committed(&self) -> u64
Sourcepub const fn load_selectivity_ratio(&self) -> Option<MetricRatio>
pub const fn load_selectivity_ratio(&self) -> Option<MetricRatio>
Returns result rows emitted per load candidate row scanned.
Sourcepub const fn load_filter_ratio(&self) -> Option<MetricRatio>
pub const fn load_filter_ratio(&self) -> Option<MetricRatio>
Returns candidate rows filtered per load candidate row scanned.
Sourcepub const fn sql_write_mutation_ratio(&self) -> Option<MetricRatio>
pub const fn sql_write_mutation_ratio(&self) -> Option<MetricRatio>
Returns SQL-mutated rows per SQL-matched row.
Sourcepub const fn sql_write_returning_ratio(&self) -> Option<MetricRatio>
pub const fn sql_write_returning_ratio(&self) -> Option<MetricRatio>
Returns SQL RETURNING rows per SQL-mutated row.
Sourcepub const fn write_index_entries_per_row(&self) -> Option<MetricRatio>
pub const fn write_index_entries_per_row(&self) -> Option<MetricRatio>
Returns primary index entries changed per write row touched.
Sourcepub const fn write_reverse_index_entries_per_row(&self) -> Option<MetricRatio>
pub const fn write_reverse_index_entries_per_row(&self) -> Option<MetricRatio>
Returns reverse-index entries changed per write row touched.
Sourcepub const fn write_relation_checks_per_row(&self) -> Option<MetricRatio>
pub const fn write_relation_checks_per_row(&self) -> Option<MetricRatio>
Returns relation checks performed per write row touched.