PrimaryKeyModelFields

Enum PrimaryKeyModelFields 

pub enum PrimaryKeyModelFields {
    Scalar(&'static FieldModel),
    Ordered(&'static [&'static FieldModel]),
}
PrimaryKeyModelFields

Borrowed primary-key field list without allocating on hot metadata paths.

Variants



Scalar(&'static FieldModel)



Ordered(&'static [&'static FieldModel])

Implementations

Source

impl PrimaryKeyModelFields

pub const fn len(self) -> usize

Return the number of fields represented by this view.

pub const fn is_empty(self) -> bool

Return whether this view has no fields.

pub fn get(self, index: usize) -> Option<&'static FieldModel>

Return the field at index.

pub const fn iter(self) -> PrimaryKeyModelFieldIter

Iterate over ordered primary-key fields.