pub struct FieldModel { /* private fields */ }Expand description
FieldModel
Runtime field metadata surfaced by macro-generated EntityModel values.
This is the smallest unit consumed by predicate validation, planning, and executor-side plan checks.
Implementations
Sourceimpl FieldModel
impl FieldModel
Sourcepub const fn nullable(&self) -> bool
pub const fn nullable(&self) -> bool
Return whether the persisted field contract permits explicit NULL.
Sourcepub const fn storage_decode(&self) -> FieldStorageDecode
pub const fn storage_decode(&self) -> FieldStorageDecode
Return the persisted field decode contract.
Sourcepub const fn leaf_codec(&self) -> LeafCodec
pub const fn leaf_codec(&self) -> LeafCodec
Return the persisted leaf payload codec.
Sourcepub const fn insert_generation(&self) -> Option<FieldInsertGeneration>
pub const fn insert_generation(&self) -> Option<FieldInsertGeneration>
Return the reduced-SQL insert-time generation contract for this field.
Sourcepub const fn write_management(&self) -> Option<FieldWriteManagement>
pub const fn write_management(&self) -> Option<FieldWriteManagement>
Return the write-boundary management contract for this field.