pub struct IndexModel { /* private fields */ }Expand description
IndexModel
Runtime-only descriptor for an index used by the executor and stores.
Keeps core decoupled from the schema Index shape.
Indexing is hash-based over Value equality for all variants.
Unique indexes enforce value equality; hash collisions surface as corruption.
Implementations
Sourceimpl IndexModel
impl IndexModel
pub const fn new( name: &'static str, store: &'static str, fields: &'static [&'static str], unique: bool, ) -> Self
Sourcepub const fn new_with_predicate(
name: &'static str,
store: &'static str,
fields: &'static [&'static str],
unique: bool,
predicate: Option<&'static str>,
) -> Self
pub const fn new_with_predicate( name: &'static str, store: &'static str, fields: &'static [&'static str], unique: bool, predicate: Option<&'static str>, ) -> Self
Construct one index descriptor with an optional conditional predicate.
Sourcepub const fn predicate(&self) -> Option<&'static str>
pub const fn predicate(&self) -> Option<&'static str>
Return optional schema-declared conditional index predicate metadata.
Sourcepub fn is_prefix_of(&self, other: &Self) -> bool
pub fn is_prefix_of(&self, other: &Self) -> bool
Whether this index’s field prefix matches the start of another index.