Module traits

Module traits 

Module: traits

Responsibility: core trait surface shared across values, entities, and visitors. Does not own: executor/runtime policy or public facade DTO behavior. Boundary: reusable domain contracts consumed throughout icydb-core.

Structs

EntityCreateMaterialization
EntityCreateMaterialization

Enums

Ordering
An Ordering is the result of a comparison between two values.
RuntimeValueKind
RuntimeValueKind

Traits

Add
The addition operator +.
AddAssign
The addition assignment operator +=.
CanisterKind
CanisterKind Marker for canister namespaces
Collection
============================================================================ QUERY VALUE BOUNDARIES
Debug
? formatting.
Default
A trait for giving a type a useful default value.
Deref
Used for immutable dereferencing operations, like *v.
DerefMut
Used for mutable dereferencing operations, like in *v = 1;.
Deserialize
A data structure that can be deserialized from any data format supported by Serde.
DeserializeOwned
A data structure that can be deserialized without borrowing any data from the deserializer.
Div
The division operator /.
DivAssign
The division assignment operator /=.
EntityCreateInput
EntityCreateInput
EntityCreateType
EntityCreateType
EntityKey
EntityKey
EntityKeyBytes
EntityKeyBytes
EntityKind
EntityKind
EntityPlacement
EntityPlacement
EntitySchema
EntitySchema
EntityValue
EntityValue
EnumValue
Eq
Trait for comparisons corresponding to equivalence relations.
FieldProjection
FieldTypeMeta
FieldTypeMeta
From
Used to do value-to-value conversions while consuming the input value. It is the reciprocal of Into.
Hash
A hashable type.
Inner
============================================================================ MISC HELPERS
KeyValueCodec
KeyValueCodec
Kind
Kind Marker for all schema/runtime nodes.
MapCollection
MapCollection
Mul
The multiplication operator *.
MulAssign
The multiplication assignment operator *=.
NumericValue
NumericValue
PartialEq
Trait for comparisons using the equality operator.
Path
Path Fully-qualified schema path.
PersistedByKindCodec
PersistedByKindCodec
PersistedFieldMetaCodec
PersistedFieldMetaCodec
PersistedFieldSlotCodec
PersistedFieldSlotCodec
PersistedStructuredFieldCodec
PersistedStructuredFieldCodec
Rem
The remainder operator %.
Repr
Repr
RuntimeValueDecode
RuntimeValueDecode
RuntimeValueEncode
RuntimeValueEncode
RuntimeValueMeta
RuntimeValueMeta
Sanitize
Marker trait: a type supports sanitization.
SanitizeAuto
Schema-defined sanitization for this node only.
SanitizeCustom
User-defined sanitization hooks.
Sanitizer
============================================================================ SANITIZATION / VALIDATION
Serialize
A data structure that can be serialized into any data format supported by Serde.
SingletonEntity
Marker for entities with exactly one logical row.
Storable
A trait with convenience methods for storing an element into a stable structure.
StorageKeyCodec
StorageKeyCodec
StorageKeyDecode
StorageKeyDecode
StoreKind
StoreKind Marker for data stores bound to a canister
Sub
The subtraction operator -.
SubAssign
The subtraction assignment operator -=.
TypeKind
TypeKind
Validate
Marker trait: a type supports validation.
ValidateAuto
Schema-defined validation for this node only.
ValidateCustom
User-defined validation hooks.
Validator
Validator
Visitable
A node that participates in visitor-based traversal.

Functions

runtime_value_btree_map_from_value
runtime_value_btree_map_from_value
runtime_value_btree_set_from_value
runtime_value_btree_set_from_value
runtime_value_collection_to_value
runtime_value_collection_to_value
runtime_value_from_value
runtime_value_from_value
runtime_value_from_vec_into
runtime_value_from_vec_into
runtime_value_from_vec_into_btree_map
runtime_value_from_vec_into_btree_map
runtime_value_from_vec_into_btree_set
runtime_value_from_vec_into_btree_set
runtime_value_into
runtime_value_into
runtime_value_map_collection_to_value
runtime_value_map_collection_to_value
runtime_value_to_value
runtime_value_to_value
runtime_value_vec_from_value
runtime_value_vec_from_value

Derive Macros

Debug
Derive macro generating an impl of the trait Debug.
Default
Derive macro generating an impl of the trait Default.
Deserialize
Eq
Derive macro generating an impl of the trait Eq. The behavior of this macro is described in detail here.
Hash
Derive macro generating an impl of the trait Hash.
PartialEq
Derive macro generating an impl of the trait PartialEq. The behavior of this macro is described in detail here.
Serialize