EntityInsertInput

Trait EntityInsertInput 

pub trait EntityInsertInput: Sized {
    type Entity: EntityValue + Default;

    // Required method
    fn materialize_insert(self) -> EntityInsertMaterialization<Self::Entity>;
}
EntityInsertInput

Insert-authored typed input for one entity. This is intentionally distinct from the readable entity shape so generated and managed fields can stay structurally un-authorable on typed inserts.

Required Associated Types

Required Methods

fn materialize_insert(self) -> EntityInsertMaterialization<Self::Entity>

Materialize one typed insert payload plus authored-slot provenance.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors