pub trait EntityKind:
EntitySchema
+ EntityPlacement
+ Kind
+ TypeKind {
const ENTITY_TAG: EntityTag;
}Expand description
EntityKind
Fully runtime-bound entity.
This is the maximum entity contract and should only be required by code that actually touches storage or execution.
Required Associated Constants
const ENTITY_TAG: EntityTag
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.