ScalarRelationTargetKey

Trait ScalarRelationTargetKey 

pub trait ScalarRelationTargetKey { }
ScalarRelationTargetKey

Marker for scalar entity key types that relation fields may target. Composite generated key structs deliberately do not implement this marker.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ScalarRelationTargetKey for ()

Source

impl ScalarRelationTargetKey for i8

Source

impl ScalarRelationTargetKey for i16

Source

impl ScalarRelationTargetKey for i32

Source

impl ScalarRelationTargetKey for i64

Source

impl ScalarRelationTargetKey for i128

Source

impl ScalarRelationTargetKey for u8

Source

impl ScalarRelationTargetKey for u16

Source

impl ScalarRelationTargetKey for u32

Source

impl ScalarRelationTargetKey for u64

Source

impl ScalarRelationTargetKey for u128

Implementors