ScalarRelationTargetKeyMatchesDeclaredPrimitive

Trait ScalarRelationTargetKeyMatchesDeclaredPrimitive 

pub trait ScalarRelationTargetKeyMatchesDeclaredPrimitive<Declared> { }
ScalarRelationTargetKeyMatchesDeclaredPrimitive

Generated relation fields use this marker to prove that the target entity has a scalar key and that the relation field’s declared primitive matches that exact scalar key type.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors