pub trait Validator<T: ?Sized> {
// Required method
fn validate(&self, value: &T, ctx: &mut dyn VisitorContext);
}Expand description
Validator allows a node to validate different types of primitives ?Sized so we can operate on str
pub trait Validator<T: ?Sized> {
// Required method
fn validate(&self, value: &T, ctx: &mut dyn VisitorContext);
}Validator allows a node to validate different types of primitives ?Sized so we can operate on str