ValueSurfaceEncode

Trait ValueSurfaceEncode 

pub trait ValueSurfaceEncode {
    // Required method
    fn to_value(&self) -> Value;
}
ValueSurfaceEncode

Narrow runtime lowering boundary for typed value surfaces that can be projected into the internal Value union. This is the encode-side owner used by generated wrappers and shared helper paths that only need one-way lowering.

Required Methods

fn to_value(&self) -> Value

Implementations on Foreign Types

Source

impl ValueSurfaceEncode for &str

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for bool

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for i8

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for i16

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for i32

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for i64

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for u8

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for u16

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for u32

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for u64

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for ()

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for String

Source

fn to_value(&self) -> Value

Source

impl ValueSurfaceEncode for Principal

Source

fn to_value(&self) -> Value

Source

impl<K, V> ValueSurfaceEncode for BTreeMap<K, V>

Source

fn to_value(&self) -> Value

Source

impl<T> ValueSurfaceEncode for BTreeSet<T>

Source

fn to_value(&self) -> Value

Source

impl<T: ValueSurfaceEncode> ValueSurfaceEncode for Option<T>

Source

fn to_value(&self) -> Value

Source

impl<T: ValueSurfaceEncode> ValueSurfaceEncode for Box<T>

Source

fn to_value(&self) -> Value

Source

impl<T: ValueSurfaceEncode> ValueSurfaceEncode for Vec<T>

Source

fn to_value(&self) -> Value

Implementors