pub fn runtime_value_from_value<T>(value: &Value) -> Option<T>where
T: RuntimeValueDecode,Expand description
Reconstruct one typed runtime value without naming its decode trait at the call site.
pub fn runtime_value_from_value<T>(value: &Value) -> Option<T>where
T: RuntimeValueDecode,Reconstruct one typed runtime value without naming its decode trait at the call site.