pub fn runtime_value_to_value<T>(value: &T) -> Valuewhere
T: ?Sized + RuntimeValueEncode,Expand description
Lower one typed runtime value without naming its encode trait at the call site.
pub fn runtime_value_to_value<T>(value: &T) -> Valuewhere
T: ?Sized + RuntimeValueEncode,Lower one typed runtime value without naming its encode trait at the call site.