InputValue

Struct InputValue 

pub struct InputValue(/* private fields */);

Implementations

Source

impl InputValue

pub const fn from_public(value: PublicValue) -> Self

Wrap one caller-authored public value without conversion.

pub const fn as_public(&self) -> &PublicValue

Borrow the canonical recursive public value.

pub fn into_public(self) -> PublicValue

Consume this boundary wrapper without conversion.

pub const fn account(value: Account) -> Self

Build an account input value.

pub const fn blob(value: Vec<u8>) -> Self

Build a blob input value.

pub const fn boolean(value: bool) -> Self

Build a boolean input value.

pub const fn date(value: Date) -> Self

Build a date input value.

pub const fn decimal(value: Decimal) -> Self

Build a decimal input value.

pub const fn duration(value: Duration) -> Self

Build a duration input value.

pub const fn float32(value: Float32) -> Self

Build a finite 32-bit floating-point input value.

pub const fn float64(value: Float64) -> Self

Build a finite 64-bit floating-point input value.

pub const fn int64(value: i64) -> Self

Build a 64-bit signed integer input value.

pub const fn int128(value: i128) -> Self

Build a 128-bit signed integer input value.

pub const fn int_big(value: IntBig) -> Self

Build an unbounded signed integer input value.

pub fn list(values: Vec<Self>) -> Self

Build a recursive list from caller-authored input values.

The owned root wrappers move into the shared recursive kernel without cloning nested values.

pub fn map(entries: Vec<(Self, Self)>) -> Self

Build a recursive map from caller-authored input key/value pairs.

The owned root wrappers move into the shared recursive kernel without cloning nested values.

pub const fn null() -> Self

Build a null input value.

pub const fn is_null(&self) -> bool

Report whether this input is null.

pub const fn principal(value: Principal) -> Self

Build a principal input value.

pub const fn subaccount(value: Subaccount) -> Self

Build a fixed subaccount input value.

pub const fn text(value: String) -> Self

Build a text input value.

pub const fn timestamp(value: Timestamp) -> Self

Build a timestamp input value.

pub const fn nat64(value: u64) -> Self

Build a 64-bit natural input value.

pub const fn nat128(value: u128) -> Self

Build a 128-bit natural input value.

pub const fn nat_big(value: NatBig) -> Self

Build an unbounded natural input value.

pub const fn ulid(value: Ulid) -> Self

Build a ULID input value.

pub const fn unit() -> Self

Build a unit input value.

pub const fn u256(value: U256) -> Self

Build a fixed-width unsigned integer input value.

pub fn enum_value(variant: &str, path: Option<&str>) -> Self

Build an enum input with an optional schema-visible type path.

pub fn loose_enum(variant: impl Into<String>) -> Self

Build an enum input whose type is resolved from its expected contract.

pub fn with_enum_payload(self, payload: Self) -> Option<Self>

Attach one recursive payload to an enum input.