#[repr(u8)]pub enum CompareOp {
Eq = 1,
Ne = 2,
Lt = 3,
Lte = 4,
Gt = 5,
Gte = 6,
In = 7,
NotIn = 8,
Contains = 9,
StartsWith = 10,
EndsWith = 11,
}Expand description
CompareOp
Variants
Eq = 1
Ne = 2
Lt = 3
Lte = 4
Gt = 5
Gte = 6
In = 7
NotIn = 8
Contains = 9
StartsWith = 10
EndsWith = 11
Implementations
Sourceimpl CompareOp
impl CompareOp
Sourcepub const fn is_equality_family(self) -> bool
pub const fn is_equality_family(self) -> bool
Return whether this operator is one symmetric equality-style compare.
Sourcepub const fn is_ordering_family(self) -> bool
pub const fn is_ordering_family(self) -> bool
Return whether this operator is one ordered range-bound compare.
Sourcepub const fn is_membership_family(self) -> bool
pub const fn is_membership_family(self) -> bool
Return whether this operator is one list-membership compare.
Sourcepub const fn is_contains_family(self) -> bool
pub const fn is_contains_family(self) -> bool
Return whether this operator is one containment compare.
Sourcepub const fn is_text_pattern_family(self) -> bool
pub const fn is_text_pattern_family(self) -> bool
Return whether this operator is one text-pattern compare.
Sourcepub const fn supports_field_compare(self) -> bool
pub const fn supports_field_compare(self) -> bool
Return whether this operator supports direct field-to-field comparison.
Sourcepub const fn lower_bound_inclusive(self) -> Option<bool>
pub const fn lower_bound_inclusive(self) -> Option<bool>
Return whether this operator contributes one lower bound and whether it is inclusive when present.
Sourcepub const fn upper_bound_inclusive(self) -> Option<bool>
pub const fn upper_bound_inclusive(self) -> Option<bool>
Return whether this operator contributes one upper bound and whether it is inclusive when present.