pub struct ExplainExecutionNodeDescriptor { /* private fields */ }Expand description
ExplainExecutionNodeDescriptor
Canonical execution-node descriptor for EXPLAIN renderers. Optional fields are node-family specific.
Implementations
Sourceimpl ExplainExecutionNodeDescriptor
impl ExplainExecutionNodeDescriptor
Sourcepub const fn node_type(&self) -> ExplainExecutionNodeType
pub const fn node_type(&self) -> ExplainExecutionNodeType
Return node type.
Sourcepub const fn execution_mode(&self) -> ExplainExecutionMode
pub const fn execution_mode(&self) -> ExplainExecutionMode
Return execution mode.
Sourcepub const fn access_strategy(&self) -> Option<&ExplainAccessPath>
pub const fn access_strategy(&self) -> Option<&ExplainAccessPath>
Borrow optional access strategy annotation.
Sourcepub fn predicate_pushdown(&self) -> Option<&str>
pub fn predicate_pushdown(&self) -> Option<&str>
Borrow optional predicate pushdown annotation.
Sourcepub const fn residual_predicate(&self) -> Option<&ExplainPredicate>
pub const fn residual_predicate(&self) -> Option<&ExplainPredicate>
Borrow optional residual predicate annotation.
Sourcepub fn projection(&self) -> Option<&str>
pub fn projection(&self) -> Option<&str>
Borrow optional projection annotation.
Sourcepub const fn ordering_source(&self) -> Option<ExplainExecutionOrderingSource>
pub const fn ordering_source(&self) -> Option<ExplainExecutionOrderingSource>
Return optional ordering source annotation.
Sourcepub const fn covering_scan(&self) -> Option<bool>
pub const fn covering_scan(&self) -> Option<bool>
Return optional covering-scan annotation.
Sourcepub const fn rows_expected(&self) -> Option<u64>
pub const fn rows_expected(&self) -> Option<u64>
Return optional row-count expectation annotation.
Sourcepub const fn node_properties(&self) -> &ExplainPropertyMap
pub const fn node_properties(&self) -> &ExplainPropertyMap
Borrow node properties.
Sourceimpl ExplainExecutionNodeDescriptor
impl ExplainExecutionNodeDescriptor
Sourcepub fn render_json_canonical(&self) -> String
pub fn render_json_canonical(&self) -> String
Render this execution subtree as canonical JSON.
Sourceimpl ExplainExecutionNodeDescriptor
impl ExplainExecutionNodeDescriptor
Sourcepub fn render_text_tree(&self) -> String
pub fn render_text_tree(&self) -> String
Render this execution subtree as a compact text tree.
Sourcepub fn render_text_tree_verbose(&self) -> String
pub fn render_text_tree_verbose(&self) -> String
Render this execution subtree as a verbose text tree with properties.
Sourcepub fn render_text_tree_verbose_with_indent(&self, indent: &str) -> String
pub fn render_text_tree_verbose_with_indent(&self, indent: &str) -> String
Render this execution subtree as one verbose text tree with one caller-owned line prefix applied to every emitted line.