pub struct ExplainRejectedIndexV1 {
pub index_name: Option<String>,
pub reason: Option<String>,
pub label: String,
}Expand description
Rejected index candidate summary recorded by the planner.
Fields
index_name: Option<String>Semantic index name when parsed from the planner rejection label.
reason: Option<String>Planner-owned rejection reason code when parsed from the rejection label.
label: StringOriginal planner rejection label.