MigrationRegistry

Struct MigrationRegistry 

pub struct MigrationRegistry { /* private fields */ }
MigrationRegistry

MigrationRegistry tracks schema migrations that have completed above the lower db::migration execution engine. This first implementation is an explicit owner object so no commit/storage layout changes are required by the schema-evolution slice.

Implementations

Source

impl MigrationRegistry

pub const fn new() -> Self

Build one empty completed-migration registry.

pub fn is_applied(&self, migration_id: EntityName, version: u64) -> bool

Return whether the migration id/version is already recorded as complete.

pub fn record_applied(&mut self, migration_id: EntityName, version: u64)

Record one migration id/version as complete.

pub fn len(&self) -> usize

Return the number of completed migration keys tracked by this registry.

pub fn is_empty(&self) -> bool

Return whether this registry currently has no completed migration keys.