pub struct WriteBatchResponse<E> { /* private fields */ }Expand description
WriteBatchResponse
Result of a batch write operation. Provides explicit access to stored entities and their identifiers.
Implementations
Sourceimpl<E> WriteBatchResponse<E>
impl<E> WriteBatchResponse<E>
Sourcepub fn entries(&self) -> &[WriteResponse<E>]
pub fn entries(&self) -> &[WriteResponse<E>]
Return all write responses.
Sourcepub fn ids(&self) -> Vec<Id<E>>where
E: EntityValue,
pub fn ids(&self) -> Vec<Id<E>>where
E: EntityValue,
Return all primary keys for correlation, reporting, and lookup.
Sourceimpl<E> WriteBatchResponse<E>
impl<E> WriteBatchResponse<E>
pub fn iter(&self) -> Iter<'_, WriteResponse<E>>