pub enum ErrorDetail {
Store(StoreError),
Query(QueryErrorDetail),
}Expand description
ErrorDetail
Structured, origin-specific error detail carried by InternalError.
This enum is intentionally extensible.
Variants
Store(StoreError)
Query(QueryErrorDetail)
Implementations
Sourceimpl ErrorDetail
impl ErrorDetail
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this structured detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail when the payload carries one.