pub enum ExecutorErrorDetail {
MutationRequiredFieldMissing,
}Expand description
Executor-specific structured error detail.
Variants
MutationRequiredFieldMissing
A complete insert or replacement omitted one or more required fields.
Implementations
Sourceimpl ExecutorErrorDetail
impl ExecutorErrorDetail
Sourcepub const fn diagnostic_code(&self) -> DiagnosticCode
pub const fn diagnostic_code(&self) -> DiagnosticCode
Return the compact diagnostic code for this executor detail.
Sourcepub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
pub const fn diagnostic_detail(&self) -> Option<DiagnosticDetail>
Return compact structured diagnostic detail for this executor detail.