pub enum MergePatchError {
InvalidShape {
expected: &'static str,
actual: &'static str,
},
CardinalityViolation {
expected: usize,
actual: usize,
},
Context {
path: String,
source: Box<Self>,
},
}Expand description
MergePatchError
Structured failures for user-driven patch application.
Variants
Implementations
Sourceimpl MergePatchError
impl MergePatchError
Sourcepub fn with_field(self, field: impl AsRef<str>) -> Self
pub fn with_field(self, field: impl AsRef<str>) -> Self
Prepend a field segment to the merge error path.
Sourcepub fn with_index(self, index: usize) -> Self
pub fn with_index(self, index: usize) -> Self
Prepend an index segment to the merge error path.