pub fn serialize_hex<T>(ty: &T) -> Result<String, SerializeError>where T: Serialize,
Serialize a value using the default canic serializer and stream the encoded bytes directly into one lowercase hex string.
canic