Module: traits
Responsibility: core trait surface shared across values, entities, and visitors.
Does not own: executor/runtime policy or public facade DTO behavior.
Boundary: reusable domain contracts consumed throughout icydb-core.
Structs
- Entity
Create Materialization - EntityCreateMaterialization
Enums
- Ordering
- An
Orderingis the result of a comparison between two values. - Runtime
Value Kind - RuntimeValueKind
Traits
- Add
- The addition operator
+. - AddAssign
- The addition assignment operator
+=. - Canister
Kind - CanisterKind Marker for canister namespaces
- Collection
- ============================================================================ QUERY VALUE BOUNDARIES
- Debug
?formatting.- Default
- A trait for giving a type a useful default value.
- Deref
- Used for immutable dereferencing operations, like
*v. - Deref
Mut - Used for mutable dereferencing operations, like in
*v = 1;. - Deserialize
- A data structure that can be deserialized from any data format supported by Serde.
- Deserialize
Owned - A data structure that can be deserialized without borrowing any data from the deserializer.
- Div
- The division operator
/. - DivAssign
- The division assignment operator
/=. - Entity
Create Input - EntityCreateInput
- Entity
Create Type - EntityCreateType
- Entity
Key - EntityKey
- Entity
KeyBytes - EntityKeyBytes
- Entity
Kind - EntityKind
- Entity
Placement - EntityPlacement
- Entity
Schema - EntitySchema
- Entity
Value - EntityValue
- Enum
Value - Eq
- Trait for comparisons corresponding to equivalence relations.
- Field
Projection - Field
Type Meta - FieldTypeMeta
- From
- Used to do value-to-value conversions while consuming the input value. It is the reciprocal of
Into. - Hash
- A hashable type.
- Inner
- ============================================================================ MISC HELPERS
- KeyValue
Codec - KeyValueCodec
- Kind
- Kind Marker for all schema/runtime nodes.
- MapCollection
- MapCollection
- Mul
- The multiplication operator
*. - MulAssign
- The multiplication assignment operator
*=. - Numeric
Value - NumericValue
- Partial
Eq - Trait for comparisons using the equality operator.
- Path
- Path Fully-qualified schema path.
- Persisted
ByKind Codec - PersistedByKindCodec
- Persisted
Field Meta Codec - PersistedFieldMetaCodec
- Persisted
Field Slot Codec - PersistedFieldSlotCodec
- Persisted
Structured Field Codec - PersistedStructuredFieldCodec
- Rem
- The remainder operator
%. - Repr
- Repr
- Runtime
Value Decode - RuntimeValueDecode
- Runtime
Value Encode - RuntimeValueEncode
- Runtime
Value Meta - RuntimeValueMeta
- Sanitize
- Marker trait: a type supports sanitization.
- Sanitize
Auto - Schema-defined sanitization for this node only.
- Sanitize
Custom - User-defined sanitization hooks.
- Sanitizer
- ============================================================================ SANITIZATION / VALIDATION
- Serialize
- A data structure that can be serialized into any data format supported by Serde.
- Singleton
Entity - Marker for entities with exactly one logical row.
- Storable
- A trait with convenience methods for storing an element into a stable structure.
- Storage
KeyCodec - StorageKeyCodec
- Storage
KeyDecode - StorageKeyDecode
- Store
Kind - StoreKind Marker for data stores bound to a canister
- Sub
- The subtraction operator
-. - SubAssign
- The subtraction assignment operator
-=. - Type
Kind - TypeKind
- Validate
- Marker trait: a type supports validation.
- Validate
Auto - Schema-defined validation for this node only.
- Validate
Custom - User-defined validation hooks.
- Validator
- Validator
- Visitable
- A node that participates in visitor-based traversal.
Functions
- runtime_
value_ btree_ map_ from_ value - runtime_value_btree_map_from_value
- runtime_
value_ btree_ set_ from_ value - runtime_value_btree_set_from_value
- runtime_
value_ collection_ to_ value - runtime_value_collection_to_value
- runtime_
value_ from_ value - runtime_value_from_value
- runtime_
value_ from_ vec_ into - runtime_value_from_vec_into
- runtime_
value_ from_ vec_ into_ btree_ map - runtime_value_from_vec_into_btree_map
- runtime_
value_ from_ vec_ into_ btree_ set - runtime_value_from_vec_into_btree_set
- runtime_
value_ into - runtime_value_into
- runtime_
value_ map_ collection_ to_ value - runtime_value_map_collection_to_value
- runtime_
value_ to_ value - runtime_value_to_value
- runtime_
value_ vec_ from_ value - runtime_value_vec_from_value
Derive Macros
- Debug
- Derive macro generating an impl of the trait
Debug. - Default
- Derive macro generating an impl of the trait
Default. - Deserialize
- Eq
- Derive macro generating an impl of the trait
Eq. The behavior of this macro is described in detail here. - Hash
- Derive macro generating an impl of the trait
Hash. - Partial
Eq - Derive macro generating an impl of the trait
PartialEq. The behavior of this macro is described in detail here. - Serialize