pub fn runtime_value_from_value<T>(value: &Value) -> Option<T>where
T: RuntimeValueDecode,Expand description
runtime_value_from_value
Hidden runtime reconstruction helper for generated code and other decode call sites that should not spell the decode trait directly. This helper is runtime-only and MUST NOT be used from persistence or storage decoding code.