pub fn runtime_value_to_value<T>(value: &T) -> Valuewhere
T: ?Sized + RuntimeValueEncode,Expand description
runtime_value_to_value
Hidden runtime lowering helper for generated code and other encode-only call sites that should not spell the encode trait directly. This helper is runtime-only and MUST NOT be used from persistence or storage encoding code.