EntityKind

Trait EntityKind 

pub trait EntityKind:
    EntitySchema
    + EntityPlacement
    + Kind
    + TypeKind { }
Fully runtime-bound entity.

This is the maximum entity contract and should only be required by code that actually touches storage or execution.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors