Hash

Trait Hash 

1.0.0 · Source
pub trait Hash {
    // Required method
    fn hash<H>(&self, state: &mut H)
       where H: Hasher;

    // Provided method
    fn hash_slice<H>(data: &[Self], state: &mut H)
       where H: Hasher,
             Self: Sized { ... }
}
A hashable type.

Types implementing Hash are able to be hashed with an instance of Hasher.

Implementing Hash

You can derive Hash with #[derive(Hash)] if all fields implement Hash. The resulting hash will be the combination of the values from calling hash on each field.

#[derive(Hash)]
struct Rustacean {
    name: String,
    country: String,
}

If you need more control over how a value is hashed, you can of course implement the Hash trait yourself:

use std::hash::{Hash, Hasher};

struct Person {
    id: u32,
    name: String,
    phone: u64,
}

impl Hash for Person {
    fn hash<H: Hasher>(&self, state: &mut H) {
        self.id.hash(state);
        self.phone.hash(state);
    }
}

Hash and Eq

When implementing both Hash and Eq, it is important that the following property holds:

k1 == k2 -> hash(k1) == hash(k2)

In other words, if two keys are equal, their hashes must also be equal. HashMap and HashSet both rely on this behavior.

Thankfully, you won’t need to worry about upholding this property when deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].

Violating this property is a logic error. The behavior resulting from a logic error is not specified, but users of the trait must ensure that such logic errors do not result in undefined behavior. This means that unsafe code must not rely on the correctness of these methods.

Prefix collisions

Implementations of hash should ensure that the data they pass to the Hasher are prefix-free. That is, values which are not equal should cause two different sequences of values to be written, and neither of the two sequences should be a prefix of the other.

For example, the standard implementation of Hash for &str passes an extra 0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.

Portability

Due to differences in endianness and type sizes, data fed by Hash to a Hasher should not be considered portable across platforms. Additionally the data passed by most standard library types should not be considered stable between compiler versions.

This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and instead should check consistency with Eq.

Serialization formats intended to be portable between platforms or compiler versions should either avoid encoding hashes or only rely on Hash and Hasher implementations that provide additional guarantees.

Required Methods

1.0.0 · Source

fn hash<H>(&self, state: &mut H)
where H: Hasher,

Feeds this value into the given Hasher.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
7920.hash(&mut hasher);
println!("Hash is {:x}!", hasher.finish());

Provided Methods

1.3.0 · Source

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher.

This method is meant as a convenience, but its implementation is also explicitly left unspecified. It isn’t guaranteed to be equivalent to repeated calls of hash and implementations of Hash should keep that in mind and call hash themselves if the slice isn’t treated as a whole unit in the PartialEq implementation.

For example, a VecDeque implementation might naïvely call as_slices and then hash_slice on each slice, but this is wrong since the two slices can change with a call to make_contiguous without affecting the PartialEq result. Since these slices aren’t treated as singular units, and instead part of a larger deque, this method cannot be used.

Examples
use std::hash::{DefaultHasher, Hash, Hasher};

let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Hash for CoercionId

Source

impl Hash for Key

1.0.0 · Source

impl Hash for icydb_core::traits::Ordering

Source

impl Hash for AsciiChar

1.44.0 · Source

impl Hash for Infallible

Source

impl Hash for Locality

1.7.0 · Source

impl Hash for IpAddr

Source

impl Hash for Ipv6MulticastScope

1.0.0 · Source

impl Hash for SocketAddr

1.55.0 · Source

impl Hash for IntErrorKind

1.0.0 · Source

impl Hash for core::sync::atomic::Ordering

1.0.0 · Source

impl Hash for ErrorKind

Source

impl Hash for byteorder::BigEndian

Source

impl Hash for byteorder::LittleEndian

Source

impl Hash for FuncMode

Source

impl Hash for candid::types::internal::Label

Source

impl Hash for TypeInner

Source

impl Hash for SnsType

Source

impl Hash for Colons

Source

impl Hash for Fixed

Source

impl Hash for Numeric

Source

impl Hash for OffsetPrecision

Source

impl Hash for Pad

Source

impl Hash for ParseErrorKind

Source

impl Hash for SecondsFormat

Source

impl Hash for chrono::month::Month

Source

impl Hash for chrono::weekday::Weekday

Source

impl Hash for Boundary

Source

impl Hash for Pattern

Source

impl Hash for Network

Source

impl Hash for UtxosFilter

Source

impl Hash for ErrorCode

Source

impl Hash for RejectCode

Source

impl Hash for CanisterInstallMode

Source

impl Hash for CanisterStatusType

Source

impl Hash for ChangeDetails

Source

impl Hash for ChangeOrigin

Source

impl Hash for CodeDeploymentMode

Source

impl Hash for EcdsaCurve

Source

impl Hash for HttpMethod

Source

impl Hash for LogVisibility

Source

impl Hash for SchnorrAlgorithm

Source

impl Hash for SchnorrAux

Source

impl Hash for SnapshotSource

Source

impl Hash for VetKDCurve

Source

impl Hash for WasmMemoryPersistence

Source

impl Hash for Tag

Source

impl Hash for minicbor::data::Type

Source

impl Hash for Sign

Source

impl Hash for strum::ParseError

Source

impl Hash for AttrStyle

Available on crate features derive or full only.
Source

impl Hash for Meta

Available on crate features derive or full only.
Source

impl Hash for Fields

Available on crate features derive or full only.
Source

impl Hash for Data

Available on crate feature derive only.
Source

impl Hash for Expr

Available on crate features derive or full only.
Source

impl Hash for Member

Source

impl Hash for PointerMutability

Available on crate feature full only.
Source

impl Hash for RangeLimits

Available on crate feature full only.
Source

impl Hash for CapturedParam

Available on crate feature full only.
Source

impl Hash for GenericParam

Available on crate features derive or full only.
Source

impl Hash for TraitBoundModifier

Available on crate features derive or full only.
Source

impl Hash for TypeParamBound

Available on crate features derive or full only.
Source

impl Hash for WherePredicate

Available on crate features derive or full only.
Source

impl Hash for FnArg

Available on crate feature full only.
Source

impl Hash for ForeignItem

Available on crate feature full only.
Source

impl Hash for ImplItem

Available on crate feature full only.
Source

impl Hash for ImplRestriction

Available on crate feature full only.
Source

impl Hash for syn::item::Item

Available on crate feature full only.
Source

impl Hash for StaticMutability

Available on crate feature full only.
Source

impl Hash for TraitItem

Available on crate feature full only.
Source

impl Hash for UseTree

Available on crate feature full only.
Source

impl Hash for Lit

Source

impl Hash for MacroDelimiter

Available on crate features derive or full only.
Source

impl Hash for BinOp

Available on crate features derive or full only.
Source

impl Hash for UnOp

Available on crate features derive or full only.
Source

impl Hash for Pat

Available on crate feature full only.
Source

impl Hash for GenericArgument

Available on crate features derive or full only.
Source

impl Hash for PathArguments

Available on crate features derive or full only.
Source

impl Hash for FieldMutability

Available on crate features derive or full only.
Source

impl Hash for Visibility

Available on crate features derive or full only.
Source

impl Hash for Stmt

Available on crate feature full only.
Source

impl Hash for ReturnType

Available on crate features derive or full only.
Source

impl Hash for syn::ty::Type

Available on crate features derive or full only.
Source

impl Hash for time::month::Month

Source

impl Hash for time::weekday::Weekday

Source

impl Hash for DecodeError

Source

impl Hash for EncodeError

Source

impl Hash for zerocopy::byteorder::BigEndian

Source

impl Hash for zerocopy::byteorder::LittleEndian

1.0.0 · Source

impl Hash for bool

1.0.0 · Source

impl Hash for char

1.0.0 · Source

impl Hash for i8

1.0.0 · Source

impl Hash for i16

1.0.0 · Source

impl Hash for i32

1.0.0 · Source

impl Hash for i64

1.0.0 · Source

impl Hash for i128

1.0.0 · Source

impl Hash for isize

1.29.0 · Source

impl Hash for !

1.0.0 · Source

impl Hash for str

1.0.0 · Source

impl Hash for u8

1.0.0 · Source

impl Hash for u16

1.0.0 · Source

impl Hash for u32

1.0.0 · Source

impl Hash for u64

1.0.0 · Source

impl Hash for u128

1.0.0 · Source

impl Hash for ()

1.0.0 · Source

impl Hash for usize

Source

impl Hash for EntityName

Source

impl Hash for IndexName

Source

impl Hash for IndexId

Source

impl Hash for IndexKey

Source

impl Hash for RawIndexKey

Source

impl Hash for FieldRef

Source

impl Hash for PlanFingerprint

Source

impl Hash for DataKey

Source

impl Hash for RawDataKey

Source

impl Hash for icydb_core::types::Account

Source

impl Hash for Blob

Source

impl Hash for icydb_core::types::Date

Source

impl Hash for icydb_core::types::Decimal

Source

impl Hash for icydb_core::types::Duration

Source

impl Hash for E8s

Source

impl Hash for E18s

Source

impl Hash for Float32

Source

impl Hash for Float64

Source

impl Hash for Int128

Source

impl Hash for icydb_core::types::Int

Source

impl Hash for Nat128

Source

impl Hash for icydb_core::types::Nat

Source

impl Hash for icydb_core::types::Principal

Source

impl Hash for Subaccount

Source

impl Hash for Timestamp

Source

impl Hash for icydb_core::types::Ulid

Source

impl Hash for Unit

Source

impl Hash for ByteString

1.64.0 · Source

impl Hash for CString

1.0.0 · Source

impl Hash for String

1.28.0 · Source

impl Hash for Layout

1.0.0 · Source

impl Hash for core::any::TypeId

Source

impl Hash for ByteStr

1.64.0 · Source

impl Hash for CStr

1.0.0 · Source

impl Hash for Error

1.33.0 · Source

impl Hash for PhantomPinned

1.0.0 · Source

impl Hash for Ipv4Addr

1.0.0 · Source

impl Hash for Ipv6Addr

1.0.0 · Source

impl Hash for SocketAddrV4

1.0.0 · Source

impl Hash for SocketAddrV6

1.0.0 · Source

impl Hash for RangeFull

1.10.0 · Source

impl Hash for Location<'_>

Source

impl Hash for Alignment

1.3.0 · Source

impl Hash for core::time::Duration

1.0.0 · Source

impl Hash for OsStr

1.0.0 · Source

impl Hash for OsString

1.1.0 · Source

impl Hash for FileType

Source

impl Hash for UCred

1.0.0 · Source

impl Hash for std::path::Path

1.0.0 · Source

impl Hash for PathBuf

1.0.0 · Source

impl Hash for PrefixComponent<'_>

1.19.0 · Source

impl Hash for ThreadId

1.8.0 · Source

impl Hash for Instant

1.8.0 · Source

impl Hash for SystemTime

Source

impl Hash for candid::types::internal::Field

Source

impl Hash for Function

Source

impl Hash for candid::types::internal::Type

Source

impl Hash for candid::types::internal::TypeId

Source

impl Hash for candid::types::number::Int

Source

impl Hash for candid::types::number::Nat

Source

impl Hash for Reserved

Source

impl Hash for canic_cdk::types::account::Account

Source

impl Hash for Cycles

Source

impl Hash for Parsed

Source

impl Hash for InternalFixed

Source

impl Hash for InternalNumeric

Source

impl Hash for OffsetFormat

Source

impl Hash for chrono::format::ParseError

Source

impl Hash for Months

Source

impl Hash for NaiveDate

Source

impl Hash for NaiveDateDaysIterator

Source

impl Hash for NaiveDateWeeksIterator

Source

impl Hash for NaiveDateTime

Source

impl Hash for IsoWeek

Source

impl Hash for Days

Source

impl Hash for NaiveWeek

Source

impl Hash for NaiveTime

Source

impl Hash for FixedOffset

Source

impl Hash for Utc

Source

impl Hash for OutOfRange

Source

impl Hash for TimeDelta

Source

impl Hash for WeekdaySet

Source

impl Hash for IdentString

Source

impl Hash for Ignored

Source

impl Hash for PreservedStrExpr

Source

impl Hash for TaskId

Source

impl Hash for GetBalanceRequest

Source

impl Hash for GetBlockHeadersRequest

Source

impl Hash for GetBlockHeadersResponse

Source

impl Hash for GetCurrentFeePercentilesRequest

Source

impl Hash for GetUtxosRequest

Source

impl Hash for GetUtxosResponse

Source

impl Hash for Outpoint

Source

impl Hash for SendTransactionRequest

Source

impl Hash for Utxo

Source

impl Hash for ic_cdk::management_canister::CreateCanisterArgs

Source

impl Hash for ic_cdk::management_canister::InstallChunkedCodeArgs

Source

impl Hash for ic_cdk::management_canister::InstallCodeArgs

Source

impl Hash for ic_cdk::management_canister::LoadCanisterSnapshotArgs

Source

impl Hash for ic_cdk::management_canister::ProvisionalCreateCanisterWithCyclesArgs

Source

impl Hash for ic_cdk::management_canister::UninstallCodeArgs

Source

impl Hash for ic_cdk::management_canister::UpdateSettingsArgs

Source

impl Hash for UserError

Source

impl Hash for Bip341

Source

impl Hash for CanisterIdRecord

Source

impl Hash for CanisterInfoArgs

Source

impl Hash for CanisterInfoResult

Source

impl Hash for CanisterLogRecord

Source

impl Hash for CanisterMetadataArgs

Source

impl Hash for CanisterMetadataResult

Source

impl Hash for CanisterSettings

Source

impl Hash for CanisterStatusResult

Source

impl Hash for Change

Source

impl Hash for ChunkHash

Source

impl Hash for CodeDeploymentRecord

Source

impl Hash for ControllersChangeRecord

Source

impl Hash for ic_management_canister_types::CreateCanisterArgs

Source

impl Hash for CreationRecord

Source

impl Hash for DefiniteCanisterSettings

Source

impl Hash for DeleteCanisterSnapshotArgs

Source

impl Hash for EcdsaKeyId

Source

impl Hash for EcdsaPublicKeyArgs

Source

impl Hash for EcdsaPublicKeyResult

Source

impl Hash for EnvironmentVariable

Source

impl Hash for FetchCanisterLogsResult

Source

impl Hash for FromCanisterRecord

Source

impl Hash for FromUserRecord

Source

impl Hash for HttpHeader

Source

impl Hash for HttpRequestResult

Source

impl Hash for ic_management_canister_types::InstallChunkedCodeArgs

Source

impl Hash for ic_management_canister_types::InstallCodeArgs

Source

impl Hash for ic_management_canister_types::LoadCanisterSnapshotArgs

Source

impl Hash for LoadSnapshotRecord

Source

impl Hash for MemoryMetrics

Source

impl Hash for NodeMetrics

Source

impl Hash for NodeMetricsHistoryArgs

Source

impl Hash for NodeMetricsHistoryRecord

Source

impl Hash for ic_management_canister_types::ProvisionalCreateCanisterWithCyclesArgs

Source

impl Hash for ProvisionalTopUpCanisterArgs

Source

impl Hash for QueryStats

Source

impl Hash for SchnorrKeyId

Source

impl Hash for SchnorrPublicKeyArgs

Source

impl Hash for SchnorrPublicKeyResult

Source

impl Hash for SignWithEcdsaArgs

Source

impl Hash for SignWithEcdsaResult

Source

impl Hash for SignWithSchnorrArgs

Source

impl Hash for SignWithSchnorrResult

Source

impl Hash for Snapshot

Source

impl Hash for SubnetInfoArgs

Source

impl Hash for SubnetInfoResult

Source

impl Hash for TakeCanisterSnapshotArgs

Source

impl Hash for TransformArgs

Source

impl Hash for ic_management_canister_types::UninstallCodeArgs

Source

impl Hash for ic_management_canister_types::UpdateSettingsArgs

Source

impl Hash for UpgradeFlags

Source

impl Hash for UploadChunkArgs

Source

impl Hash for VetKDDeriveKeyArgs

Source

impl Hash for VetKDDeriveKeyResult

Source

impl Hash for VetKDKeyId

Source

impl Hash for VetKDPublicKeyArgs

Source

impl Hash for VetKDPublicKeyResult

Source

impl Hash for ic_principal::Principal

Source

impl Hash for icrc_ledger_types::icrc1::account::Account

Source

impl Hash for Memo

Source

impl Hash for ByteSlice

Source

impl Hash for ByteVec

Source

impl Hash for minicbor::data::Int

Source

impl Hash for BigInt

Source

impl Hash for BigUint

Source

impl Hash for Ident

Source

impl Hash for rust_decimal::decimal::Decimal

Source

impl Hash for ByteBuf

Source

impl Hash for Bytes

Source

impl Hash for DefaultKey

Source

impl Hash for KeyData

Source

impl Hash for Attribute

Available on crate features derive or full only.
Source

impl Hash for MetaList

Available on crate features derive or full only.
Source

impl Hash for MetaNameValue

Available on crate features derive or full only.
Source

impl Hash for syn::data::Field

Available on crate features derive or full only.
Source

impl Hash for FieldsNamed

Available on crate features derive or full only.
Source

impl Hash for FieldsUnnamed

Available on crate features derive or full only.
Source

impl Hash for Variant

Available on crate features derive or full only.
Source

impl Hash for DataEnum

Available on crate feature derive only.
Source

impl Hash for DataStruct

Available on crate feature derive only.
Source

impl Hash for DataUnion

Available on crate feature derive only.
Source

impl Hash for DeriveInput

Available on crate feature derive only.
Source

impl Hash for Arm

Available on crate feature full only.
Source

impl Hash for ExprArray

Available on crate feature full only.
Source

impl Hash for ExprAssign

Available on crate feature full only.
Source

impl Hash for ExprAsync

Available on crate feature full only.
Source

impl Hash for ExprAwait

Available on crate feature full only.
Source

impl Hash for ExprBinary

Available on crate features derive or full only.
Source

impl Hash for ExprBlock

Available on crate feature full only.
Source

impl Hash for ExprBreak

Available on crate feature full only.
Source

impl Hash for ExprCall

Available on crate features derive or full only.
Source

impl Hash for ExprCast

Available on crate features derive or full only.
Source

impl Hash for ExprClosure

Available on crate feature full only.
Source

impl Hash for ExprConst

Available on crate feature full only.
Source

impl Hash for ExprContinue

Available on crate feature full only.
Source

impl Hash for ExprField

Available on crate features derive or full only.
Source

impl Hash for ExprForLoop

Available on crate feature full only.
Source

impl Hash for ExprGroup

Available on crate features derive or full only.
Source

impl Hash for ExprIf

Available on crate feature full only.
Source

impl Hash for ExprIndex

Available on crate features derive or full only.
Source

impl Hash for ExprInfer

Available on crate feature full only.
Source

impl Hash for ExprLet

Available on crate feature full only.
Source

impl Hash for ExprLit

Available on crate features derive or full only.
Source

impl Hash for ExprLoop

Available on crate feature full only.
Source

impl Hash for ExprMacro

Available on crate features derive or full only.
Source

impl Hash for ExprMatch

Available on crate feature full only.
Source

impl Hash for ExprMethodCall

Available on crate features derive or full only.
Source

impl Hash for ExprParen

Available on crate features derive or full only.
Source

impl Hash for ExprPath

Available on crate features derive or full only.
Source

impl Hash for ExprRange

Available on crate feature full only.
Source

impl Hash for ExprRawAddr

Available on crate feature full only.
Source

impl Hash for ExprReference

Available on crate features derive or full only.
Source

impl Hash for ExprRepeat

Available on crate feature full only.
Source

impl Hash for ExprReturn

Available on crate feature full only.
Source

impl Hash for ExprStruct

Available on crate features derive or full only.
Source

impl Hash for ExprTry

Available on crate feature full only.
Source

impl Hash for ExprTryBlock

Available on crate feature full only.
Source

impl Hash for ExprTuple

Available on crate features derive or full only.
Source

impl Hash for ExprUnary

Available on crate features derive or full only.
Source

impl Hash for ExprUnsafe

Available on crate feature full only.
Source

impl Hash for ExprWhile

Available on crate feature full only.
Source

impl Hash for ExprYield

Available on crate feature full only.
Source

impl Hash for FieldValue

Available on crate features derive or full only.
Source

impl Hash for Index

Source

impl Hash for syn::expr::Label

Available on crate feature full only.
Source

impl Hash for File

Available on crate feature full only.
Source

impl Hash for BoundLifetimes

Available on crate features derive or full only.
Source

impl Hash for ConstParam

Available on crate features derive or full only.
Source

impl Hash for Generics

Available on crate features derive or full only.
Source

impl Hash for LifetimeParam

Available on crate features derive or full only.
Source

impl Hash for PreciseCapture

Available on crate feature full only.
Source

impl Hash for PredicateLifetime

Available on crate features derive or full only.
Source

impl Hash for PredicateType

Available on crate features derive or full only.
Source

impl Hash for TraitBound

Available on crate features derive or full only.
Source

impl Hash for TypeParam

Available on crate features derive or full only.
Source

impl Hash for WhereClause

Available on crate features derive or full only.
Source

impl Hash for ForeignItemFn

Available on crate feature full only.
Source

impl Hash for ForeignItemMacro

Available on crate feature full only.
Source

impl Hash for ForeignItemStatic

Available on crate feature full only.
Source

impl Hash for ForeignItemType

Available on crate feature full only.
Source

impl Hash for ImplItemConst

Available on crate feature full only.
Source

impl Hash for ImplItemFn

Available on crate feature full only.
Source

impl Hash for ImplItemMacro

Available on crate feature full only.
Source

impl Hash for ImplItemType

Available on crate feature full only.
Source

impl Hash for ItemConst

Available on crate feature full only.
Source

impl Hash for ItemEnum

Available on crate feature full only.
Source

impl Hash for ItemExternCrate

Available on crate feature full only.
Source

impl Hash for ItemFn

Available on crate feature full only.
Source

impl Hash for ItemForeignMod

Available on crate feature full only.
Source

impl Hash for ItemImpl

Available on crate feature full only.
Source

impl Hash for ItemMacro

Available on crate feature full only.
Source

impl Hash for ItemMod

Available on crate feature full only.
Source

impl Hash for ItemStatic

Available on crate feature full only.
Source

impl Hash for ItemStruct

Available on crate feature full only.
Source

impl Hash for ItemTrait

Available on crate feature full only.
Source

impl Hash for ItemTraitAlias

Available on crate feature full only.
Source

impl Hash for ItemType

Available on crate feature full only.
Source

impl Hash for ItemUnion

Available on crate feature full only.
Source

impl Hash for ItemUse

Available on crate feature full only.
Source

impl Hash for Receiver

Available on crate feature full only.
Source

impl Hash for Signature

Available on crate feature full only.
Source

impl Hash for TraitItemConst

Available on crate feature full only.
Source

impl Hash for TraitItemFn

Available on crate feature full only.
Source

impl Hash for TraitItemMacro

Available on crate feature full only.
Source

impl Hash for TraitItemType

Available on crate feature full only.
Source

impl Hash for UseGlob

Available on crate feature full only.
Source

impl Hash for UseGroup

Available on crate feature full only.
Source

impl Hash for UseName

Available on crate feature full only.
Source

impl Hash for UsePath

Available on crate feature full only.
Source

impl Hash for UseRename

Available on crate feature full only.
Source

impl Hash for Variadic

Available on crate feature full only.
Source

impl Hash for Lifetime

Source

impl Hash for LitBool

Source

impl Hash for LitByte

Available on crate feature extra-traits only.
Source

impl Hash for LitByteStr

Available on crate feature extra-traits only.
Source

impl Hash for LitCStr

Available on crate feature extra-traits only.
Source

impl Hash for LitChar

Available on crate feature extra-traits only.
Source

impl Hash for LitFloat

Available on crate feature extra-traits only.
Source

impl Hash for LitInt

Available on crate feature extra-traits only.
Source

impl Hash for LitStr

Available on crate feature extra-traits only.
Source

impl Hash for syn::mac::Macro

Available on crate features derive or full only.
Source

impl Hash for Nothing

Available on crate feature extra-traits only.
Source

impl Hash for FieldPat

Available on crate feature full only.
Source

impl Hash for PatIdent

Available on crate feature full only.
Source

impl Hash for PatOr

Available on crate feature full only.
Source

impl Hash for PatParen

Available on crate feature full only.
Source

impl Hash for PatReference

Available on crate feature full only.
Source

impl Hash for PatRest

Available on crate feature full only.
Source

impl Hash for PatSlice

Available on crate feature full only.
Source

impl Hash for PatStruct

Available on crate feature full only.
Source

impl Hash for PatTuple

Available on crate feature full only.
Source

impl Hash for PatTupleStruct

Available on crate feature full only.
Source

impl Hash for PatType

Available on crate feature full only.
Source

impl Hash for PatWild

Available on crate feature full only.
Source

impl Hash for AngleBracketedGenericArguments

Available on crate features derive or full only.
Source

impl Hash for AssocConst

Available on crate features derive or full only.
Source

impl Hash for AssocType

Available on crate features derive or full only.
Source

impl Hash for Constraint

Available on crate features derive or full only.
Source

impl Hash for ParenthesizedGenericArguments

Available on crate features derive or full only.
Source

impl Hash for syn::path::Path

Available on crate features derive or full only.
Source

impl Hash for PathSegment

Available on crate features derive or full only.
Source

impl Hash for QSelf

Available on crate features derive or full only.
Source

impl Hash for VisRestricted

Available on crate features derive or full only.
Source

impl Hash for Block

Available on crate feature full only.
Source

impl Hash for Local

Available on crate feature full only.
Source

impl Hash for LocalInit

Available on crate feature full only.
Source

impl Hash for StmtMacro

Available on crate feature full only.
Source

impl Hash for Abstract

Available on crate feature extra-traits only.
Source

impl Hash for And

Available on crate feature extra-traits only.
Source

impl Hash for AndAnd

Available on crate feature extra-traits only.
Source

impl Hash for AndEq

Available on crate feature extra-traits only.
Source

impl Hash for As

Available on crate feature extra-traits only.
Source

impl Hash for Async

Available on crate feature extra-traits only.
Source

impl Hash for At

Available on crate feature extra-traits only.
Source

impl Hash for Auto

Available on crate feature extra-traits only.
Source

impl Hash for Await

Available on crate feature extra-traits only.
Source

impl Hash for Become

Available on crate feature extra-traits only.
Source

impl Hash for syn::token::Box

Available on crate feature extra-traits only.
Source

impl Hash for Brace

Available on crate feature extra-traits only.
Source

impl Hash for Bracket

Available on crate feature extra-traits only.
Source

impl Hash for Break

Available on crate feature extra-traits only.
Source

impl Hash for Caret

Available on crate feature extra-traits only.
Source

impl Hash for CaretEq

Available on crate feature extra-traits only.
Source

impl Hash for Colon

Available on crate feature extra-traits only.
Source

impl Hash for Comma

Available on crate feature extra-traits only.
Source

impl Hash for Const

Available on crate feature extra-traits only.
Source

impl Hash for Continue

Available on crate feature extra-traits only.
Source

impl Hash for Crate

Available on crate feature extra-traits only.
Source

impl Hash for Default

Available on crate feature extra-traits only.
Source

impl Hash for Do

Available on crate feature extra-traits only.
Source

impl Hash for Dollar

Available on crate feature extra-traits only.
Source

impl Hash for Dot

Available on crate feature extra-traits only.
Source

impl Hash for DotDot

Available on crate feature extra-traits only.
Source

impl Hash for DotDotDot

Available on crate feature extra-traits only.
Source

impl Hash for DotDotEq

Available on crate feature extra-traits only.
Source

impl Hash for Dyn

Available on crate feature extra-traits only.
Source

impl Hash for Else

Available on crate feature extra-traits only.
Source

impl Hash for Enum

Available on crate feature extra-traits only.
Source

impl Hash for Eq

Available on crate feature extra-traits only.
Source

impl Hash for EqEq

Available on crate feature extra-traits only.
Source

impl Hash for Extern

Available on crate feature extra-traits only.
Source

impl Hash for FatArrow

Available on crate feature extra-traits only.
Source

impl Hash for Final

Available on crate feature extra-traits only.
Source

impl Hash for Fn

Available on crate feature extra-traits only.
Source

impl Hash for For

Available on crate feature extra-traits only.
Source

impl Hash for Ge

Available on crate feature extra-traits only.
Source

impl Hash for Group

Available on crate feature extra-traits only.
Source

impl Hash for Gt

Available on crate feature extra-traits only.
Source

impl Hash for If

Available on crate feature extra-traits only.
Source

impl Hash for Impl

Available on crate feature extra-traits only.
Source

impl Hash for In

Available on crate feature extra-traits only.
Source

impl Hash for LArrow

Available on crate feature extra-traits only.
Source

impl Hash for Le

Available on crate feature extra-traits only.
Source

impl Hash for Let

Available on crate feature extra-traits only.
Source

impl Hash for Loop

Available on crate feature extra-traits only.
Source

impl Hash for Lt

Available on crate feature extra-traits only.
Source

impl Hash for syn::token::Macro

Available on crate feature extra-traits only.
Source

impl Hash for Match

Available on crate feature extra-traits only.
Source

impl Hash for Minus

Available on crate feature extra-traits only.
Source

impl Hash for MinusEq

Available on crate feature extra-traits only.
Source

impl Hash for Mod

Available on crate feature extra-traits only.
Source

impl Hash for Move

Available on crate feature extra-traits only.
Source

impl Hash for Mut

Available on crate feature extra-traits only.
Source

impl Hash for Ne

Available on crate feature extra-traits only.
Source

impl Hash for Not

Available on crate feature extra-traits only.
Source

impl Hash for Or

Available on crate feature extra-traits only.
Source

impl Hash for OrEq

Available on crate feature extra-traits only.
Source

impl Hash for OrOr

Available on crate feature extra-traits only.
Source

impl Hash for Override

Available on crate feature extra-traits only.
Source

impl Hash for Paren

Available on crate feature extra-traits only.
Source

impl Hash for PathSep

Available on crate feature extra-traits only.
Source

impl Hash for Percent

Available on crate feature extra-traits only.
Source

impl Hash for PercentEq

Available on crate feature extra-traits only.
Source

impl Hash for Plus

Available on crate feature extra-traits only.
Source

impl Hash for PlusEq

Available on crate feature extra-traits only.
Source

impl Hash for Pound

Available on crate feature extra-traits only.
Source

impl Hash for Priv

Available on crate feature extra-traits only.
Source

impl Hash for Pub

Available on crate feature extra-traits only.
Source

impl Hash for Question

Available on crate feature extra-traits only.
Source

impl Hash for RArrow

Available on crate feature extra-traits only.
Source

impl Hash for Raw

Available on crate feature extra-traits only.
Source

impl Hash for Ref

Available on crate feature extra-traits only.
Source

impl Hash for Return

Available on crate feature extra-traits only.
Source

impl Hash for SelfType

Available on crate feature extra-traits only.
Source

impl Hash for SelfValue

Available on crate feature extra-traits only.
Source

impl Hash for Semi

Available on crate feature extra-traits only.
Source

impl Hash for Shl

Available on crate feature extra-traits only.
Source

impl Hash for ShlEq

Available on crate feature extra-traits only.
Source

impl Hash for Shr

Available on crate feature extra-traits only.
Source

impl Hash for ShrEq

Available on crate feature extra-traits only.
Source

impl Hash for Slash

Available on crate feature extra-traits only.
Source

impl Hash for SlashEq

Available on crate feature extra-traits only.
Source

impl Hash for Star

Available on crate feature extra-traits only.
Source

impl Hash for StarEq

Available on crate feature extra-traits only.
Source

impl Hash for Static

Available on crate feature extra-traits only.
Source

impl Hash for Struct

Available on crate feature extra-traits only.
Source

impl Hash for Super

Available on crate feature extra-traits only.
Source

impl Hash for Tilde

Available on crate feature extra-traits only.
Source

impl Hash for Trait

Available on crate feature extra-traits only.
Source

impl Hash for Try

Available on crate feature extra-traits only.
Source

impl Hash for syn::token::Type

Available on crate feature extra-traits only.
Source

impl Hash for Typeof

Available on crate feature extra-traits only.
Source

impl Hash for Underscore

Available on crate feature extra-traits only.
Source

impl Hash for Union

Available on crate feature extra-traits only.
Source

impl Hash for Unsafe

Available on crate feature extra-traits only.
Source

impl Hash for Unsized

Available on crate feature extra-traits only.
Source

impl Hash for Use

Available on crate feature extra-traits only.
Source

impl Hash for Virtual

Available on crate feature extra-traits only.
Source

impl Hash for Where

Available on crate feature extra-traits only.
Source

impl Hash for While

Available on crate feature extra-traits only.
Source

impl Hash for Yield

Available on crate feature extra-traits only.
Source

impl Hash for Abi

Available on crate features derive or full only.
Source

impl Hash for BareFnArg

Available on crate features derive or full only.
Source

impl Hash for BareVariadic

Available on crate features derive or full only.
Source

impl Hash for TypeArray

Available on crate features derive or full only.
Source

impl Hash for TypeBareFn

Available on crate features derive or full only.
Source

impl Hash for TypeGroup

Available on crate features derive or full only.
Source

impl Hash for TypeImplTrait

Available on crate features derive or full only.
Source

impl Hash for TypeInfer

Available on crate features derive or full only.
Source

impl Hash for TypeMacro

Available on crate features derive or full only.
Source

impl Hash for TypeNever

Available on crate features derive or full only.
Source

impl Hash for TypeParen

Available on crate features derive or full only.
Source

impl Hash for TypePath

Available on crate features derive or full only.
Source

impl Hash for TypePtr

Available on crate features derive or full only.
Source

impl Hash for TypeReference

Available on crate features derive or full only.
Source

impl Hash for TypeSlice

Available on crate features derive or full only.
Source

impl Hash for TypeTraitObject

Available on crate features derive or full only.
Source

impl Hash for TypeTuple

Available on crate features derive or full only.
Source

impl Hash for time::date::Date

Source

impl Hash for time::duration::Duration

Source

impl Hash for ComponentRange

Source

impl Hash for OffsetDateTime

Source

impl Hash for PrimitiveDateTime

Source

impl Hash for Time

Source

impl Hash for UtcDateTime

Source

impl Hash for UtcOffset

Source

impl Hash for ATerm

Source

impl Hash for B0

Source

impl Hash for B1

Source

impl Hash for Z0

Source

impl Hash for Equal

Source

impl Hash for Greater

Source

impl Hash for Less

Source

impl Hash for UTerm

Source

impl Hash for ulid::Ulid

1.0.0 · Source

impl<'a> Hash for Component<'a>

1.0.0 · Source

impl<'a> Hash for Prefix<'a>

Source

impl<'a> Hash for chrono::format::Item<'a>

Source

impl<'a> Hash for PhantomContravariantLifetime<'a>

Source

impl<'a> Hash for PhantomCovariantLifetime<'a>

Source

impl<'a> Hash for PhantomInvariantLifetime<'a>

Source

impl<'a> Hash for ImplGenerics<'a>

Available on crate feature extra-traits only.
Source

impl<'a> Hash for Turbofish<'a>

Available on crate feature extra-traits only.
Source

impl<'a> Hash for TypeGenerics<'a>

Available on crate feature extra-traits only.
Source

impl<'b> Hash for Case<'b>

Source

impl<'r, R> Hash for UnwrapMut<'r, R>
where R: Hash + TryRngCore + ?Sized,

Source

impl<A> Hash for arrayvec::array_string::ArrayString<A>
where A: Array<Item = u8> + Copy,

Source

impl<A> Hash for arrayvec::ArrayVec<A>
where A: Array, <A as Array>::Item: Hash,

Source

impl<A> Hash for SmallVec<A>
where A: Array, <A as Array>::Item: Hash,

1.0.0 · Source

impl<B> Hash for Cow<'_, B>
where B: Hash + ToOwned + ?Sized,

1.55.0 · Source

impl<B, C> Hash for ControlFlow<B, C>
where B: Hash, C: Hash,

Source

impl<Dyn> Hash for DynMetadata<Dyn>
where Dyn: ?Sized,

1.4.0 · Source

impl<F> Hash for F
where F: FnPtr,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::Range<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for core::ops::range::RangeFrom<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<Idx> Hash for RangeTo<Idx>
where Idx: Hash,

1.26.0 · Source

impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for core::range::Range<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for core::range::RangeFrom<Idx>
where Idx: Hash,

1.95.0 · Source

impl<Idx> Hash for core::range::RangeInclusive<Idx>
where Idx: Hash,

Source

impl<Idx> Hash for core::range::RangeToInclusive<Idx>
where Idx: Hash,

1.0.0 · Source

impl<K, V, A> Hash for BTreeMap<K, V, A>
where K: Hash, V: Hash, A: Allocator + Clone,

Source

impl<O> Hash for F32<O>
where O: Hash,

Source

impl<O> Hash for F64<O>
where O: Hash,

Source

impl<O> Hash for I16<O>
where O: Hash,

Source

impl<O> Hash for I32<O>
where O: Hash,

Source

impl<O> Hash for I64<O>
where O: Hash,

Source

impl<O> Hash for I128<O>
where O: Hash,

Source

impl<O> Hash for Isize<O>
where O: Hash,

Source

impl<O> Hash for U16<O>
where O: Hash,

Source

impl<O> Hash for U32<O>
where O: Hash,

Source

impl<O> Hash for U64<O>
where O: Hash,

Source

impl<O> Hash for U128<O>
where O: Hash,

Source

impl<O> Hash for Usize<O>
where O: Hash,

1.41.0 · Source

impl<Ptr> Hash for Pin<Ptr>
where Ptr: Deref, <Ptr as Deref>::Target: Hash,

Source

impl<R> Hash for UnwrapErr<R>
where R: Hash + TryRngCore,

Source

impl<Storage> Hash for ic_certification::hash_tree::Label<Storage>
where Storage: Hash + AsRef<[u8]>,

Source

impl<Storage> Hash for ic_certification::hash_tree::Label<Storage>
where Storage: Hash + AsRef<[u8]>,

1.17.0 · Source

impl<T> Hash for Bound<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Option<T>
where T: Hash,

1.36.0 · Source

impl<T> Hash for Poll<T>
where T: Hash,

Source

impl<T> Hash for LocalResult<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for *const T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for *mut T
where T: ?Sized,

1.0.0 · Source

impl<T> Hash for &T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for &mut T
where T: Hash + ?Sized,

1.0.0 · Source

impl<T> Hash for [T]
where T: Hash,

1.0.0 · Source

impl<T> Hash for (T₁, T₂, …, Tₙ)
where T: Hash,

This trait is implemented for tuples up to twelve items long.

1.19.0 · Source

impl<T> Hash for Reverse<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for PhantomData<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomContravariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomCovariant<T>
where T: ?Sized,

Source

impl<T> Hash for PhantomInvariant<T>
where T: ?Sized,

1.20.0 · Source

impl<T> Hash for ManuallyDrop<T>
where T: Hash + ?Sized,

1.21.0 · Source

impl<T> Hash for Discriminant<T>

1.28.0 · Source

impl<T> Hash for NonZero<T>

1.74.0 · Source

impl<T> Hash for Saturating<T>
where T: Hash,

1.0.0 · Source

impl<T> Hash for Wrapping<T>
where T: Hash,

1.25.0 · Source

impl<T> Hash for NonNull<T>
where T: ?Sized,

Source

impl<T> Hash for Exclusive<T>
where T: Sync + Hash + ?Sized,

Source

impl<T> Hash for Unalign<T>
where T: Unaligned + Hash,

1.0.0 · Source

impl<T, A> Hash for alloc::boxed::Box<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for BTreeSet<T, A>
where T: Hash, A: Allocator + Clone,

1.0.0 · Source

impl<T, A> Hash for LinkedList<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for VecDeque<T, A>
where T: Hash, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Rc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueRc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Arc<T, A>
where T: Hash + ?Sized, A: Allocator,

Source

impl<T, A> Hash for UniqueArc<T, A>
where T: Hash + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Hash for Vec<T, A>
where T: Hash, A: Allocator,

The hash of a vector is the same as that of the corresponding slice, as required by the core::borrow::Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));
1.0.0 · Source

impl<T, E> Hash for Result<T, E>
where T: Hash, E: Hash,

Source

impl<T, N> Hash for GenericArray<T, N>
where T: Hash, N: ArrayLength<T>,

Source

impl<T, P> Hash for Punctuated<T, P>
where T: Hash, P: Hash,

Available on crate feature extra-traits only.
Source

impl<T, const CAP: usize> Hash for arrayvec::arrayvec::ArrayVec<T, CAP>
where T: Hash,

1.0.0 · Source

impl<T, const N: usize> Hash for [T; N]
where T: Hash,

The hash of an array is the same as that of the corresponding slice, as required by the Borrow implementation.

use std::hash::BuildHasher;

let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));
Source

impl<T, const N: usize> Hash for Simd<T, N>
where T: SimdElement + Hash,

Source

impl<Tz> Hash for chrono::date::Date<Tz>
where Tz: TimeZone,

Source

impl<Tz> Hash for DateTime<Tz>
where Tz: TimeZone,

Source

impl<U> Hash for NInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U> Hash for PInt<U>
where U: Hash + Unsigned + NonZero,

Source

impl<U, B> Hash for UInt<U, B>
where U: Hash, B: Hash,

Source

impl<V, A> Hash for TArr<V, A>
where V: Hash, A: Hash,

Source

impl<Y, R> Hash for CoroutineState<Y, R>
where Y: Hash, R: Hash,

Source

impl<const CAP: usize> Hash for arrayvec::array_string::ArrayString<CAP>

Source

impl<const MIN: i8, const MAX: i8> Hash for OptionRangedI8<MIN, MAX>

Source

impl<const MIN: i8, const MAX: i8> Hash for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for OptionRangedI16<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Hash for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for OptionRangedI32<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Hash for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for OptionRangedI64<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Hash for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for OptionRangedI128<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Hash for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for OptionRangedIsize<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Hash for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for OptionRangedU8<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Hash for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for OptionRangedU16<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Hash for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for OptionRangedU32<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Hash for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for OptionRangedU64<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Hash for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for OptionRangedU128<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Hash for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for OptionRangedUsize<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Hash for RangedUsize<MIN, MAX>

Source

impl<const N: usize> Hash for minicbor::bytes::ByteArray<N>

Source

impl<const N: usize> Hash for serde_bytes::bytearray::ByteArray<N>

Source

impl<const SIZE: usize> Hash for WriteBuffer<SIZE>