pub trait Hash {
// Required method
fn hash<H>(&self, state: &mut H)
where H: Hasher;
// Provided method
fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher,
Self: Sized { ... }
}Expand description
A hashable type.
Types implementing Hash are able to be hashed with an instance of
Hasher.
Implementing Hash
You can derive Hash with #[derive(Hash)] if all fields implement Hash.
The resulting hash will be the combination of the values from calling
hash on each field.
#[derive(Hash)]
struct Rustacean {
name: String,
country: String,
}If you need more control over how a value is hashed, you can of course
implement the Hash trait yourself:
use std::hash::{Hash, Hasher};
struct Person {
id: u32,
name: String,
phone: u64,
}
impl Hash for Person {
fn hash<H: Hasher>(&self, state: &mut H) {
self.id.hash(state);
self.phone.hash(state);
}
}Hash and Eq
When implementing both Hash and Eq, it is important that the following
property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must also be equal.
HashMap and HashSet both rely on this behavior.
Thankfully, you won’t need to worry about upholding this property when
deriving both Eq and Hash with #[derive(PartialEq, Eq, Hash)].
Violating this property is a logic error. The behavior resulting from a logic error is not
specified, but users of the trait must ensure that such logic errors do not result in
undefined behavior. This means that unsafe code must not rely on the correctness of these
methods.
Prefix collisions
Implementations of hash should ensure that the data they
pass to the Hasher are prefix-free. That is,
values which are not equal should cause two different sequences of values to be written,
and neither of the two sequences should be a prefix of the other.
For example, the standard implementation of Hash for &str passes an extra
0xFF byte to the Hasher so that the values ("ab", "c") and ("a", "bc") hash differently.
Portability
Due to differences in endianness and type sizes, data fed by Hash to a Hasher
should not be considered portable across platforms. Additionally the data passed by most
standard library types should not be considered stable between compiler versions.
This means tests shouldn’t probe hard-coded hash values or data fed to a Hasher and
instead should check consistency with Eq.
Serialization formats intended to be portable between platforms or compiler versions should
either avoid encoding hashes or only rely on Hash and Hasher implementations that
provide additional guarantees.
Required Methods
Provided Methods
1.3.0 · Sourcefn hash_slice<H>(data: &[Self], state: &mut H)
fn hash_slice<H>(data: &[Self], state: &mut H)
Feeds a slice of this type into the given Hasher.
This method is meant as a convenience, but its implementation is
also explicitly left unspecified. It isn’t guaranteed to be
equivalent to repeated calls of hash and implementations of
Hash should keep that in mind and call hash themselves
if the slice isn’t treated as a whole unit in the PartialEq
implementation.
For example, a VecDeque implementation might naïvely call
as_slices and then hash_slice on each slice, but this
is wrong since the two slices can change with a call to
make_contiguous without affecting the PartialEq
result. Since these slices aren’t treated as singular
units, and instead part of a larger deque, this method cannot
be used.
Examples
use std::hash::{DefaultHasher, Hash, Hasher};
let mut hasher = DefaultHasher::new();
let numbers = [6, 28, 496, 8128];
Hash::hash_slice(&numbers, &mut hasher);
println!("Hash is {:x}!", hasher.finish());Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Hash for CoercionId
impl Hash for Key
impl Hash for icydb_core::traits::Ordering
impl Hash for AsciiChar
impl Hash for Infallible
impl Hash for Locality
impl Hash for IpAddr
impl Hash for Ipv6MulticastScope
impl Hash for SocketAddr
impl Hash for IntErrorKind
impl Hash for core::sync::atomic::Ordering
impl Hash for ErrorKind
impl Hash for byteorder::BigEndian
impl Hash for byteorder::LittleEndian
impl Hash for FuncMode
impl Hash for candid::types::internal::Label
impl Hash for TypeInner
impl Hash for SnsType
impl Hash for Colons
impl Hash for Fixed
impl Hash for Numeric
impl Hash for OffsetPrecision
impl Hash for Pad
impl Hash for ParseErrorKind
impl Hash for SecondsFormat
impl Hash for chrono::month::Month
impl Hash for chrono::weekday::Weekday
impl Hash for Boundary
impl Hash for Pattern
impl Hash for Network
impl Hash for UtxosFilter
impl Hash for ErrorCode
impl Hash for RejectCode
impl Hash for CanisterInstallMode
impl Hash for CanisterStatusType
impl Hash for ChangeDetails
impl Hash for ChangeOrigin
impl Hash for CodeDeploymentMode
impl Hash for EcdsaCurve
impl Hash for HttpMethod
impl Hash for LogVisibility
impl Hash for SchnorrAlgorithm
impl Hash for SchnorrAux
impl Hash for SnapshotSource
impl Hash for VetKDCurve
impl Hash for WasmMemoryPersistence
impl Hash for Tag
impl Hash for minicbor::data::Type
impl Hash for Sign
impl Hash for strum::ParseError
impl Hash for AttrStyle
derive or full only.impl Hash for Meta
derive or full only.impl Hash for Fields
derive or full only.impl Hash for Data
derive only.impl Hash for Expr
derive or full only.impl Hash for Member
impl Hash for PointerMutability
full only.impl Hash for RangeLimits
full only.impl Hash for CapturedParam
full only.impl Hash for GenericParam
derive or full only.impl Hash for TraitBoundModifier
derive or full only.impl Hash for TypeParamBound
derive or full only.impl Hash for WherePredicate
derive or full only.impl Hash for FnArg
full only.impl Hash for ForeignItem
full only.impl Hash for ImplItem
full only.impl Hash for ImplRestriction
full only.impl Hash for syn::item::Item
full only.impl Hash for StaticMutability
full only.impl Hash for TraitItem
full only.impl Hash for UseTree
full only.impl Hash for Lit
impl Hash for MacroDelimiter
derive or full only.impl Hash for BinOp
derive or full only.impl Hash for UnOp
derive or full only.impl Hash for Pat
full only.impl Hash for GenericArgument
derive or full only.impl Hash for PathArguments
derive or full only.impl Hash for FieldMutability
derive or full only.impl Hash for Visibility
derive or full only.impl Hash for Stmt
full only.impl Hash for ReturnType
derive or full only.impl Hash for syn::ty::Type
derive or full only.impl Hash for time::month::Month
impl Hash for time::weekday::Weekday
impl Hash for DecodeError
impl Hash for EncodeError
impl Hash for zerocopy::byteorder::BigEndian
impl Hash for zerocopy::byteorder::LittleEndian
impl Hash for bool
impl Hash for char
impl Hash for i8
impl Hash for i16
impl Hash for i32
impl Hash for i64
impl Hash for i128
impl Hash for isize
impl Hash for !
impl Hash for str
impl Hash for u8
impl Hash for u16
impl Hash for u32
impl Hash for u64
impl Hash for u128
impl Hash for ()
impl Hash for usize
impl Hash for EntityName
impl Hash for IndexName
impl Hash for IndexId
impl Hash for IndexKey
impl Hash for RawIndexKey
impl Hash for FieldRef
impl Hash for PlanFingerprint
impl Hash for DataKey
impl Hash for RawDataKey
impl Hash for icydb_core::types::Account
impl Hash for Blob
impl Hash for icydb_core::types::Date
impl Hash for icydb_core::types::Decimal
impl Hash for icydb_core::types::Duration
impl Hash for E8s
impl Hash for E18s
impl Hash for Float32
impl Hash for Float64
impl Hash for Int128
impl Hash for icydb_core::types::Int
impl Hash for Nat128
impl Hash for icydb_core::types::Nat
impl Hash for icydb_core::types::Principal
impl Hash for Subaccount
impl Hash for Timestamp
impl Hash for icydb_core::types::Ulid
impl Hash for Unit
impl Hash for ByteString
impl Hash for CString
impl Hash for String
impl Hash for Layout
impl Hash for core::any::TypeId
impl Hash for ByteStr
impl Hash for CStr
impl Hash for Error
impl Hash for PhantomPinned
impl Hash for Ipv4Addr
impl Hash for Ipv6Addr
impl Hash for SocketAddrV4
impl Hash for SocketAddrV6
impl Hash for RangeFull
impl Hash for Location<'_>
impl Hash for Alignment
impl Hash for core::time::Duration
impl Hash for OsStr
impl Hash for OsString
impl Hash for FileType
impl Hash for UCred
impl Hash for std::path::Path
impl Hash for PathBuf
impl Hash for PrefixComponent<'_>
impl Hash for ThreadId
impl Hash for Instant
impl Hash for SystemTime
impl Hash for candid::types::internal::Field
impl Hash for Function
impl Hash for candid::types::internal::Type
impl Hash for candid::types::internal::TypeId
impl Hash for candid::types::number::Int
impl Hash for candid::types::number::Nat
impl Hash for Reserved
impl Hash for canic_cdk::types::account::Account
impl Hash for Cycles
impl Hash for Parsed
impl Hash for InternalFixed
impl Hash for InternalNumeric
impl Hash for OffsetFormat
impl Hash for chrono::format::ParseError
impl Hash for Months
impl Hash for NaiveDate
impl Hash for NaiveDateDaysIterator
impl Hash for NaiveDateWeeksIterator
impl Hash for NaiveDateTime
impl Hash for IsoWeek
impl Hash for Days
impl Hash for NaiveWeek
impl Hash for NaiveTime
impl Hash for FixedOffset
impl Hash for Utc
impl Hash for OutOfRange
impl Hash for TimeDelta
impl Hash for WeekdaySet
impl Hash for IdentString
impl Hash for Ignored
impl Hash for PreservedStrExpr
impl Hash for TaskId
impl Hash for GetBalanceRequest
impl Hash for GetBlockHeadersRequest
impl Hash for GetBlockHeadersResponse
impl Hash for GetCurrentFeePercentilesRequest
impl Hash for GetUtxosRequest
impl Hash for GetUtxosResponse
impl Hash for Outpoint
impl Hash for SendTransactionRequest
impl Hash for Utxo
impl Hash for ic_cdk::management_canister::CreateCanisterArgs
impl Hash for ic_cdk::management_canister::InstallChunkedCodeArgs
impl Hash for ic_cdk::management_canister::InstallCodeArgs
impl Hash for ic_cdk::management_canister::LoadCanisterSnapshotArgs
impl Hash for ic_cdk::management_canister::ProvisionalCreateCanisterWithCyclesArgs
impl Hash for ic_cdk::management_canister::UninstallCodeArgs
impl Hash for ic_cdk::management_canister::UpdateSettingsArgs
impl Hash for UserError
impl Hash for Bip341
impl Hash for CanisterIdRecord
impl Hash for CanisterInfoArgs
impl Hash for CanisterInfoResult
impl Hash for CanisterLogRecord
impl Hash for CanisterMetadataArgs
impl Hash for CanisterMetadataResult
impl Hash for CanisterSettings
impl Hash for CanisterStatusResult
impl Hash for Change
impl Hash for ChunkHash
impl Hash for CodeDeploymentRecord
impl Hash for ControllersChangeRecord
impl Hash for ic_management_canister_types::CreateCanisterArgs
impl Hash for CreationRecord
impl Hash for DefiniteCanisterSettings
impl Hash for DeleteCanisterSnapshotArgs
impl Hash for EcdsaKeyId
impl Hash for EcdsaPublicKeyArgs
impl Hash for EcdsaPublicKeyResult
impl Hash for EnvironmentVariable
impl Hash for FetchCanisterLogsResult
impl Hash for FromCanisterRecord
impl Hash for FromUserRecord
impl Hash for HttpHeader
impl Hash for HttpRequestResult
impl Hash for ic_management_canister_types::InstallChunkedCodeArgs
impl Hash for ic_management_canister_types::InstallCodeArgs
impl Hash for ic_management_canister_types::LoadCanisterSnapshotArgs
impl Hash for LoadSnapshotRecord
impl Hash for MemoryMetrics
impl Hash for NodeMetrics
impl Hash for NodeMetricsHistoryArgs
impl Hash for NodeMetricsHistoryRecord
impl Hash for ic_management_canister_types::ProvisionalCreateCanisterWithCyclesArgs
impl Hash for ProvisionalTopUpCanisterArgs
impl Hash for QueryStats
impl Hash for SchnorrKeyId
impl Hash for SchnorrPublicKeyArgs
impl Hash for SchnorrPublicKeyResult
impl Hash for SignWithEcdsaArgs
impl Hash for SignWithEcdsaResult
impl Hash for SignWithSchnorrArgs
impl Hash for SignWithSchnorrResult
impl Hash for Snapshot
impl Hash for SubnetInfoArgs
impl Hash for SubnetInfoResult
impl Hash for TakeCanisterSnapshotArgs
impl Hash for TransformArgs
impl Hash for ic_management_canister_types::UninstallCodeArgs
impl Hash for ic_management_canister_types::UpdateSettingsArgs
impl Hash for UpgradeFlags
impl Hash for UploadChunkArgs
impl Hash for VetKDDeriveKeyArgs
impl Hash for VetKDDeriveKeyResult
impl Hash for VetKDKeyId
impl Hash for VetKDPublicKeyArgs
impl Hash for VetKDPublicKeyResult
impl Hash for ic_principal::Principal
impl Hash for icrc_ledger_types::icrc1::account::Account
impl Hash for Memo
impl Hash for ByteSlice
impl Hash for ByteVec
impl Hash for minicbor::data::Int
impl Hash for BigInt
impl Hash for BigUint
impl Hash for Ident
impl Hash for rust_decimal::decimal::Decimal
impl Hash for ByteBuf
impl Hash for Bytes
impl Hash for DefaultKey
impl Hash for KeyData
impl Hash for Attribute
derive or full only.impl Hash for MetaList
derive or full only.impl Hash for MetaNameValue
derive or full only.impl Hash for syn::data::Field
derive or full only.impl Hash for FieldsNamed
derive or full only.impl Hash for FieldsUnnamed
derive or full only.impl Hash for Variant
derive or full only.impl Hash for DataEnum
derive only.impl Hash for DataStruct
derive only.impl Hash for DataUnion
derive only.impl Hash for DeriveInput
derive only.impl Hash for Arm
full only.impl Hash for ExprArray
full only.impl Hash for ExprAssign
full only.impl Hash for ExprAsync
full only.impl Hash for ExprAwait
full only.impl Hash for ExprBinary
derive or full only.impl Hash for ExprBlock
full only.impl Hash for ExprBreak
full only.impl Hash for ExprCall
derive or full only.impl Hash for ExprCast
derive or full only.impl Hash for ExprClosure
full only.impl Hash for ExprConst
full only.impl Hash for ExprContinue
full only.impl Hash for ExprField
derive or full only.impl Hash for ExprForLoop
full only.impl Hash for ExprGroup
derive or full only.impl Hash for ExprIf
full only.impl Hash for ExprIndex
derive or full only.impl Hash for ExprInfer
full only.impl Hash for ExprLet
full only.impl Hash for ExprLit
derive or full only.impl Hash for ExprLoop
full only.impl Hash for ExprMacro
derive or full only.impl Hash for ExprMatch
full only.impl Hash for ExprMethodCall
derive or full only.impl Hash for ExprParen
derive or full only.impl Hash for ExprPath
derive or full only.impl Hash for ExprRange
full only.impl Hash for ExprRawAddr
full only.impl Hash for ExprReference
derive or full only.impl Hash for ExprRepeat
full only.impl Hash for ExprReturn
full only.impl Hash for ExprStruct
derive or full only.impl Hash for ExprTry
full only.impl Hash for ExprTryBlock
full only.impl Hash for ExprTuple
derive or full only.impl Hash for ExprUnary
derive or full only.impl Hash for ExprUnsafe
full only.impl Hash for ExprWhile
full only.impl Hash for ExprYield
full only.impl Hash for FieldValue
derive or full only.impl Hash for Index
impl Hash for syn::expr::Label
full only.impl Hash for File
full only.impl Hash for BoundLifetimes
derive or full only.impl Hash for ConstParam
derive or full only.impl Hash for Generics
derive or full only.impl Hash for LifetimeParam
derive or full only.impl Hash for PreciseCapture
full only.impl Hash for PredicateLifetime
derive or full only.impl Hash for PredicateType
derive or full only.impl Hash for TraitBound
derive or full only.impl Hash for TypeParam
derive or full only.impl Hash for WhereClause
derive or full only.impl Hash for ForeignItemFn
full only.impl Hash for ForeignItemMacro
full only.impl Hash for ForeignItemStatic
full only.impl Hash for ForeignItemType
full only.impl Hash for ImplItemConst
full only.impl Hash for ImplItemFn
full only.impl Hash for ImplItemMacro
full only.impl Hash for ImplItemType
full only.impl Hash for ItemConst
full only.impl Hash for ItemEnum
full only.impl Hash for ItemExternCrate
full only.impl Hash for ItemFn
full only.impl Hash for ItemForeignMod
full only.impl Hash for ItemImpl
full only.impl Hash for ItemMacro
full only.impl Hash for ItemMod
full only.impl Hash for ItemStatic
full only.impl Hash for ItemStruct
full only.impl Hash for ItemTrait
full only.impl Hash for ItemTraitAlias
full only.impl Hash for ItemType
full only.impl Hash for ItemUnion
full only.impl Hash for ItemUse
full only.impl Hash for Receiver
full only.impl Hash for Signature
full only.impl Hash for TraitItemConst
full only.impl Hash for TraitItemFn
full only.impl Hash for TraitItemMacro
full only.impl Hash for TraitItemType
full only.impl Hash for UseGlob
full only.impl Hash for UseGroup
full only.impl Hash for UseName
full only.impl Hash for UsePath
full only.impl Hash for UseRename
full only.impl Hash for Variadic
full only.impl Hash for Lifetime
impl Hash for LitBool
impl Hash for LitByte
extra-traits only.impl Hash for LitByteStr
extra-traits only.impl Hash for LitCStr
extra-traits only.impl Hash for LitChar
extra-traits only.impl Hash for LitFloat
extra-traits only.impl Hash for LitInt
extra-traits only.impl Hash for LitStr
extra-traits only.impl Hash for syn::mac::Macro
derive or full only.impl Hash for Nothing
extra-traits only.impl Hash for FieldPat
full only.impl Hash for PatIdent
full only.impl Hash for PatOr
full only.impl Hash for PatParen
full only.impl Hash for PatReference
full only.impl Hash for PatRest
full only.impl Hash for PatSlice
full only.impl Hash for PatStruct
full only.impl Hash for PatTuple
full only.impl Hash for PatTupleStruct
full only.impl Hash for PatType
full only.impl Hash for PatWild
full only.impl Hash for AngleBracketedGenericArguments
derive or full only.impl Hash for AssocConst
derive or full only.impl Hash for AssocType
derive or full only.impl Hash for Constraint
derive or full only.impl Hash for ParenthesizedGenericArguments
derive or full only.impl Hash for syn::path::Path
derive or full only.impl Hash for PathSegment
derive or full only.impl Hash for QSelf
derive or full only.impl Hash for VisRestricted
derive or full only.impl Hash for Block
full only.impl Hash for Local
full only.impl Hash for LocalInit
full only.impl Hash for StmtMacro
full only.impl Hash for Abstract
extra-traits only.impl Hash for And
extra-traits only.impl Hash for AndAnd
extra-traits only.impl Hash for AndEq
extra-traits only.impl Hash for As
extra-traits only.impl Hash for Async
extra-traits only.impl Hash for At
extra-traits only.impl Hash for Auto
extra-traits only.impl Hash for Await
extra-traits only.impl Hash for Become
extra-traits only.impl Hash for syn::token::Box
extra-traits only.impl Hash for Brace
extra-traits only.impl Hash for Bracket
extra-traits only.impl Hash for Break
extra-traits only.impl Hash for Caret
extra-traits only.impl Hash for CaretEq
extra-traits only.impl Hash for Colon
extra-traits only.impl Hash for Comma
extra-traits only.impl Hash for Const
extra-traits only.impl Hash for Continue
extra-traits only.impl Hash for Crate
extra-traits only.impl Hash for Default
extra-traits only.impl Hash for Do
extra-traits only.impl Hash for Dollar
extra-traits only.impl Hash for Dot
extra-traits only.impl Hash for DotDot
extra-traits only.impl Hash for DotDotDot
extra-traits only.impl Hash for DotDotEq
extra-traits only.impl Hash for Dyn
extra-traits only.impl Hash for Else
extra-traits only.impl Hash for Enum
extra-traits only.impl Hash for Eq
extra-traits only.impl Hash for EqEq
extra-traits only.impl Hash for Extern
extra-traits only.impl Hash for FatArrow
extra-traits only.impl Hash for Final
extra-traits only.impl Hash for Fn
extra-traits only.impl Hash for For
extra-traits only.impl Hash for Ge
extra-traits only.impl Hash for Group
extra-traits only.impl Hash for Gt
extra-traits only.impl Hash for If
extra-traits only.impl Hash for Impl
extra-traits only.impl Hash for In
extra-traits only.impl Hash for LArrow
extra-traits only.impl Hash for Le
extra-traits only.impl Hash for Let
extra-traits only.impl Hash for Loop
extra-traits only.impl Hash for Lt
extra-traits only.impl Hash for syn::token::Macro
extra-traits only.impl Hash for Match
extra-traits only.impl Hash for Minus
extra-traits only.impl Hash for MinusEq
extra-traits only.impl Hash for Mod
extra-traits only.impl Hash for Move
extra-traits only.impl Hash for Mut
extra-traits only.impl Hash for Ne
extra-traits only.impl Hash for Not
extra-traits only.impl Hash for Or
extra-traits only.impl Hash for OrEq
extra-traits only.impl Hash for OrOr
extra-traits only.impl Hash for Override
extra-traits only.impl Hash for Paren
extra-traits only.impl Hash for PathSep
extra-traits only.impl Hash for Percent
extra-traits only.impl Hash for PercentEq
extra-traits only.impl Hash for Plus
extra-traits only.impl Hash for PlusEq
extra-traits only.impl Hash for Pound
extra-traits only.impl Hash for Priv
extra-traits only.impl Hash for Pub
extra-traits only.impl Hash for Question
extra-traits only.impl Hash for RArrow
extra-traits only.impl Hash for Raw
extra-traits only.impl Hash for Ref
extra-traits only.impl Hash for Return
extra-traits only.impl Hash for SelfType
extra-traits only.impl Hash for SelfValue
extra-traits only.impl Hash for Semi
extra-traits only.impl Hash for Shl
extra-traits only.impl Hash for ShlEq
extra-traits only.impl Hash for Shr
extra-traits only.impl Hash for ShrEq
extra-traits only.impl Hash for Slash
extra-traits only.impl Hash for SlashEq
extra-traits only.impl Hash for Star
extra-traits only.impl Hash for StarEq
extra-traits only.impl Hash for Static
extra-traits only.impl Hash for Struct
extra-traits only.impl Hash for Super
extra-traits only.impl Hash for Tilde
extra-traits only.impl Hash for Trait
extra-traits only.impl Hash for Try
extra-traits only.impl Hash for syn::token::Type
extra-traits only.impl Hash for Typeof
extra-traits only.impl Hash for Underscore
extra-traits only.impl Hash for Union
extra-traits only.impl Hash for Unsafe
extra-traits only.impl Hash for Unsized
extra-traits only.impl Hash for Use
extra-traits only.impl Hash for Virtual
extra-traits only.impl Hash for Where
extra-traits only.impl Hash for While
extra-traits only.impl Hash for Yield
extra-traits only.impl Hash for Abi
derive or full only.impl Hash for BareFnArg
derive or full only.impl Hash for BareVariadic
derive or full only.impl Hash for TypeArray
derive or full only.impl Hash for TypeBareFn
derive or full only.impl Hash for TypeGroup
derive or full only.impl Hash for TypeImplTrait
derive or full only.impl Hash for TypeInfer
derive or full only.impl Hash for TypeMacro
derive or full only.impl Hash for TypeNever
derive or full only.impl Hash for TypeParen
derive or full only.impl Hash for TypePath
derive or full only.impl Hash for TypePtr
derive or full only.impl Hash for TypeReference
derive or full only.impl Hash for TypeSlice
derive or full only.impl Hash for TypeTraitObject
derive or full only.impl Hash for TypeTuple
derive or full only.impl Hash for time::date::Date
impl Hash for time::duration::Duration
impl Hash for ComponentRange
impl Hash for OffsetDateTime
impl Hash for PrimitiveDateTime
impl Hash for Time
impl Hash for UtcDateTime
impl Hash for UtcOffset
impl Hash for ATerm
impl Hash for B0
impl Hash for B1
impl Hash for Z0
impl Hash for Equal
impl Hash for Greater
impl Hash for Less
impl Hash for UTerm
impl Hash for ulid::Ulid
impl<'a> Hash for Component<'a>
impl<'a> Hash for Prefix<'a>
impl<'a> Hash for chrono::format::Item<'a>
impl<'a> Hash for PhantomContravariantLifetime<'a>
impl<'a> Hash for PhantomCovariantLifetime<'a>
impl<'a> Hash for PhantomInvariantLifetime<'a>
impl<'a> Hash for ImplGenerics<'a>
extra-traits only.impl<'a> Hash for Turbofish<'a>
extra-traits only.impl<'a> Hash for TypeGenerics<'a>
extra-traits only.impl<'b> Hash for Case<'b>
impl<'r, R> Hash for UnwrapMut<'r, R>
impl<A> Hash for arrayvec::array_string::ArrayString<A>
impl<A> Hash for arrayvec::ArrayVec<A>
impl<A> Hash for SmallVec<A>
impl<B> Hash for Cow<'_, B>
impl<B, C> Hash for ControlFlow<B, C>
impl<Dyn> Hash for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<F> Hash for Fwhere
F: FnPtr,
impl<Idx> Hash for core::ops::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeTo<Idx>where
Idx: Hash,
impl<Idx> Hash for core::ops::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::Range<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeFrom<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for core::range::RangeToInclusive<Idx>where
Idx: Hash,
impl<K, V, A> Hash for BTreeMap<K, V, A>
impl<O> Hash for F32<O>where
O: Hash,
impl<O> Hash for F64<O>where
O: Hash,
impl<O> Hash for I16<O>where
O: Hash,
impl<O> Hash for I32<O>where
O: Hash,
impl<O> Hash for I64<O>where
O: Hash,
impl<O> Hash for I128<O>where
O: Hash,
impl<O> Hash for Isize<O>where
O: Hash,
impl<O> Hash for U16<O>where
O: Hash,
impl<O> Hash for U32<O>where
O: Hash,
impl<O> Hash for U64<O>where
O: Hash,
impl<O> Hash for U128<O>where
O: Hash,
impl<O> Hash for Usize<O>where
O: Hash,
impl<Ptr> Hash for Pin<Ptr>
impl<R> Hash for UnwrapErr<R>where
R: Hash + TryRngCore,
impl<Storage> Hash for ic_certification::hash_tree::Label<Storage>
impl<Storage> Hash for ic_certification::hash_tree::Label<Storage>
impl<T> Hash for Bound<T>where
T: Hash,
impl<T> Hash for Option<T>where
T: Hash,
impl<T> Hash for Poll<T>where
T: Hash,
impl<T> Hash for LocalResult<T>where
T: Hash,
impl<T> Hash for *const Twhere
T: ?Sized,
impl<T> Hash for *mut Twhere
T: ?Sized,
impl<T> Hash for &T
impl<T> Hash for &mut T
impl<T> Hash for [T]where
T: Hash,
impl<T> Hash for (T₁, T₂, …, Tₙ)where
T: Hash,
This trait is implemented for tuples up to twelve items long.
impl<T> Hash for Reverse<T>where
T: Hash,
impl<T> Hash for PhantomData<T>where
T: ?Sized,
impl<T> Hash for PhantomContravariant<T>where
T: ?Sized,
impl<T> Hash for PhantomCovariant<T>where
T: ?Sized,
impl<T> Hash for PhantomInvariant<T>where
T: ?Sized,
impl<T> Hash for ManuallyDrop<T>
impl<T> Hash for Discriminant<T>
impl<T> Hash for NonZero<T>where
T: ZeroablePrimitive + Hash,
impl<T> Hash for Saturating<T>where
T: Hash,
impl<T> Hash for Wrapping<T>where
T: Hash,
impl<T> Hash for NonNull<T>where
T: ?Sized,
impl<T> Hash for Exclusive<T>
impl<T> Hash for Unalign<T>
impl<T, A> Hash for alloc::boxed::Box<T, A>
impl<T, A> Hash for BTreeSet<T, A>
impl<T, A> Hash for LinkedList<T, A>
impl<T, A> Hash for VecDeque<T, A>
impl<T, A> Hash for Rc<T, A>
impl<T, A> Hash for UniqueRc<T, A>
impl<T, A> Hash for Arc<T, A>
impl<T, A> Hash for UniqueArc<T, A>
impl<T, A> Hash for Vec<T, A>
The hash of a vector is the same as that of the corresponding slice,
as required by the core::borrow::Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let v: Vec<u8> = vec![0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(v), b.hash_one(s));impl<T, E> Hash for Result<T, E>
impl<T, N> Hash for GenericArray<T, N>where
T: Hash,
N: ArrayLength<T>,
impl<T, P> Hash for Punctuated<T, P>
extra-traits only.impl<T, const CAP: usize> Hash for arrayvec::arrayvec::ArrayVec<T, CAP>where
T: Hash,
impl<T, const N: usize> Hash for [T; N]where
T: Hash,
The hash of an array is the same as that of the corresponding slice,
as required by the Borrow implementation.
use std::hash::BuildHasher;
let b = std::hash::RandomState::new();
let a: [u8; 3] = [0xa8, 0x3c, 0x09];
let s: &[u8] = &[0xa8, 0x3c, 0x09];
assert_eq!(b.hash_one(a), b.hash_one(s));