Sub

Trait Sub 

1.0.0 (const: unstable) · Source
pub trait Sub<Rhs = Self> {
    type Output;

    // Required method
    fn sub(self, rhs: Rhs) -> Self::Output;
}
The subtraction operator -.

Note that Rhs is Self by default, but this is not mandatory. For example, std::time::SystemTime implements Sub<Duration>, which permits operations of the form SystemTime = SystemTime - Duration.

Examples

Subtractable points

use std::ops::Sub;

#[derive(Debug, Copy, Clone, PartialEq)]
struct Point {
    x: i32,
    y: i32,
}

impl Sub for Point {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Self {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 3, y: 3 } - Point { x: 2, y: 3 },
           Point { x: 1, y: 0 });

Implementing Sub with generics

Here is an example of the same Point struct implementing the Sub trait using generics.

use std::ops::Sub;

#[derive(Debug, PartialEq)]
struct Point<T> {
    x: T,
    y: T,
}

// Notice that the implementation uses the associated type `Output`.
impl<T: Sub<Output = T>> Sub for Point<T> {
    type Output = Self;

    fn sub(self, other: Self) -> Self::Output {
        Point {
            x: self.x - other.x,
            y: self.y - other.y,
        }
    }
}

assert_eq!(Point { x: 2, y: 3 } - Point { x: 1, y: 0 },
           Point { x: 1, y: 3 });

Required Associated Types

1.0.0 · Source

type Output

The resulting type after applying the - operator.

Required Methods

1.0.0 · Source

fn sub(self, rhs: Rhs) -> Self::Output

Performs the - operation.

Example
assert_eq!(12 - 1, 11);

Implementors

1.0.0 (const: unstable) · Source

impl Sub for f16

1.0.0 (const: unstable) · Source

impl Sub for f32

1.0.0 (const: unstable) · Source

impl Sub for f64

1.0.0 (const: unstable) · Source

impl Sub for f128

1.0.0 (const: unstable) · Source

impl Sub for i8

1.0.0 (const: unstable) · Source

impl Sub for i16

1.0.0 (const: unstable) · Source

impl Sub for i32

1.0.0 (const: unstable) · Source

impl Sub for i64

1.0.0 (const: unstable) · Source

impl Sub for i128

1.0.0 (const: unstable) · Source

impl Sub for isize

1.0.0 (const: unstable) · Source

impl Sub for u8

1.0.0 (const: unstable) · Source

impl Sub for u16

1.0.0 (const: unstable) · Source

impl Sub for u32

1.0.0 (const: unstable) · Source

impl Sub for u64

1.0.0 (const: unstable) · Source

impl Sub for u128

1.0.0 (const: unstable) · Source

impl Sub for usize

Source

impl Sub for icydb_core::types::Date

Source

impl Sub for Decimal

Source

impl Sub for icydb_core::types::Duration

Source

impl Sub for Int128

Source

impl Sub for icydb_core::types::Int

Source

impl Sub for Nat128

Source

impl Sub for icydb_core::types::Nat

Source

impl Sub for Timestamp

Source

impl Sub for Assume

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub for Saturating<usize>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i8>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i16>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i32>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i64>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<i128>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<isize>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u8>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u16>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u32>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u64>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<u128>

1.0.0 (const: unstable) · Source

impl Sub for Wrapping<usize>

1.3.0 (const: unstable) · Source

impl Sub for core::time::Duration

1.8.0 · Source

impl Sub for Instant

Source

impl Sub for candid::types::number::Int

Source

impl Sub for candid::types::number::Nat

Source

impl Sub for Cycles

Source

impl Sub for bf16

Source

impl Sub for f16

Source

impl Sub for BigInt

Source

impl Sub for BigUint

Source

impl Sub for time::date::Date

Source

impl Sub for time::duration::Duration

Source

impl Sub for OffsetDateTime

Source

impl Sub for PrimitiveDateTime

Source

impl Sub for Time

Source

impl Sub for UtcDateTime

Source

impl Sub for ATerm

Source

impl Sub for Z0

Z0 - Z0 = Z0

Source

impl Sub for UTerm

UTerm - UTerm = UTerm

1.0.0 (const: unstable) · Source

impl Sub<&f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<&f16> for f16

1.0.0 (const: unstable) · Source

impl Sub<&f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<&f32> for f32

1.0.0 (const: unstable) · Source

impl Sub<&f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<&f64> for f64

1.0.0 (const: unstable) · Source

impl Sub<&f128> for &f128

1.0.0 (const: unstable) · Source

impl Sub<&f128> for f128

1.0.0 (const: unstable) · Source

impl Sub<&i8> for &i8

Source

impl Sub<&i8> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i8> for i8

Source

impl Sub<&i8> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for &i16

Source

impl Sub<&i16> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i16> for i16

Source

impl Sub<&i16> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for &i32

Source

impl Sub<&i32> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i32> for i32

Source

impl Sub<&i32> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for &i64

Source

impl Sub<&i64> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i64> for i64

Source

impl Sub<&i64> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for &i128

Source

impl Sub<&i128> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&i128> for i128

Source

impl Sub<&i128> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for &isize

Source

impl Sub<&isize> for &BigInt

1.0.0 (const: unstable) · Source

impl Sub<&isize> for isize

Source

impl Sub<&isize> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<&u8> for &u8

Source

impl Sub<&u8> for &BigInt

Source

impl Sub<&u8> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u8> for u8

Source

impl Sub<&u8> for BigInt

Source

impl Sub<&u8> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for &u16

Source

impl Sub<&u16> for &BigInt

Source

impl Sub<&u16> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u16> for u16

Source

impl Sub<&u16> for BigInt

Source

impl Sub<&u16> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for &u32

Source

impl Sub<&u32> for &BigInt

Source

impl Sub<&u32> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u32> for u32

Source

impl Sub<&u32> for BigInt

Source

impl Sub<&u32> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for &u64

Source

impl Sub<&u64> for &BigInt

Source

impl Sub<&u64> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u64> for u64

Source

impl Sub<&u64> for BigInt

Source

impl Sub<&u64> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for &u128

Source

impl Sub<&u128> for &BigInt

Source

impl Sub<&u128> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&u128> for u128

Source

impl Sub<&u128> for BigInt

Source

impl Sub<&u128> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for &usize

Source

impl Sub<&usize> for &BigInt

Source

impl Sub<&usize> for &BigUint

1.0.0 (const: unstable) · Source

impl Sub<&usize> for usize

Source

impl Sub<&usize> for BigInt

Source

impl Sub<&usize> for BigUint

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i8>> for Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i16>> for Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i32>> for Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i64>> for Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<i128>> for Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<isize>> for Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u8>> for Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u16>> for Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u32>> for Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u64>> for Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<u128>> for Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for &Saturating<usize>

1.74.0 (const: unstable) · Source

impl Sub<&Saturating<usize>> for Saturating<usize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i8>> for Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i16>> for Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i32>> for Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i64>> for Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<i128>> for Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<isize>> for Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u8>> for Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u16>> for Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u32>> for Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u64>> for Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<u128>> for Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for &Wrapping<usize>

1.14.0 (const: unstable) · Source

impl Sub<&Wrapping<usize>> for Wrapping<usize>

Source

impl Sub<&bf16> for &bf16

Source

impl Sub<&bf16> for bf16

Source

impl Sub<&f16> for &f16

Source

impl Sub<&f16> for f16

Source

impl Sub<&BigInt> for &i8

Source

impl Sub<&BigInt> for &i16

Source

impl Sub<&BigInt> for &i32

Source

impl Sub<&BigInt> for &i64

Source

impl Sub<&BigInt> for &i128

Source

impl Sub<&BigInt> for &isize

Source

impl Sub<&BigInt> for &u8

Source

impl Sub<&BigInt> for &u16

Source

impl Sub<&BigInt> for &u32

Source

impl Sub<&BigInt> for &u64

Source

impl Sub<&BigInt> for &u128

Source

impl Sub<&BigInt> for &usize

Source

impl Sub<&BigInt> for &BigInt

Source

impl Sub<&BigInt> for i8

Source

impl Sub<&BigInt> for i16

Source

impl Sub<&BigInt> for i32

Source

impl Sub<&BigInt> for i64

Source

impl Sub<&BigInt> for i128

Source

impl Sub<&BigInt> for isize

Source

impl Sub<&BigInt> for u8

Source

impl Sub<&BigInt> for u16

Source

impl Sub<&BigInt> for u32

Source

impl Sub<&BigInt> for u64

Source

impl Sub<&BigInt> for u128

Source

impl Sub<&BigInt> for usize

Source

impl Sub<&BigInt> for BigInt

Source

impl Sub<&BigUint> for &u8

Source

impl Sub<&BigUint> for &u16

Source

impl Sub<&BigUint> for &u32

Source

impl Sub<&BigUint> for &u64

Source

impl Sub<&BigUint> for &u128

Source

impl Sub<&BigUint> for &usize

Source

impl Sub<&BigUint> for &BigUint

Source

impl Sub<&BigUint> for u8

Source

impl Sub<&BigUint> for u16

Source

impl Sub<&BigUint> for u32

Source

impl Sub<&BigUint> for u64

Source

impl Sub<&BigUint> for u128

Source

impl Sub<&BigUint> for usize

Source

impl Sub<&BigUint> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<f16> for &f16

1.0.0 (const: unstable) · Source

impl Sub<f32> for &f32

1.0.0 (const: unstable) · Source

impl Sub<f64> for &f64

1.0.0 (const: unstable) · Source

impl Sub<f128> for &f128

1.0.0 (const: unstable) · Source

impl Sub<i8> for &i8

Source

impl Sub<i8> for &BigInt

Source

impl Sub<i8> for candid::types::number::Int

Source

impl Sub<i8> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<i16> for &i16

Source

impl Sub<i16> for &BigInt

Source

impl Sub<i16> for candid::types::number::Int

Source

impl Sub<i16> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<i32> for &i32

Source

impl Sub<i32> for &BigInt

Source

impl Sub<i32> for candid::types::number::Int

Source

impl Sub<i32> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<i64> for &i64

Source

impl Sub<i64> for &BigInt

Source

impl Sub<i64> for candid::types::number::Int

Source

impl Sub<i64> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<i128> for &i128

Source

impl Sub<i128> for &BigInt

Source

impl Sub<i128> for candid::types::number::Int

Source

impl Sub<i128> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<isize> for &isize

Source

impl Sub<isize> for &BigInt

Source

impl Sub<isize> for candid::types::number::Int

Source

impl Sub<isize> for BigInt

1.0.0 (const: unstable) · Source

impl Sub<u8> for &u8

Source

impl Sub<u8> for &BigInt

Source

impl Sub<u8> for &BigUint

Source

impl Sub<u8> for candid::types::number::Int

Source

impl Sub<u8> for candid::types::number::Nat

Source

impl Sub<u8> for BigInt

Source

impl Sub<u8> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u16> for &u16

Source

impl Sub<u16> for &BigInt

Source

impl Sub<u16> for &BigUint

Source

impl Sub<u16> for candid::types::number::Int

Source

impl Sub<u16> for candid::types::number::Nat

Source

impl Sub<u16> for BigInt

Source

impl Sub<u16> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u32> for &u32

Source

impl Sub<u32> for &BigInt

Source

impl Sub<u32> for &BigUint

Source

impl Sub<u32> for candid::types::number::Int

Source

impl Sub<u32> for candid::types::number::Nat

Source

impl Sub<u32> for BigInt

Source

impl Sub<u32> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u64> for &u64

Source

impl Sub<u64> for &BigInt

Source

impl Sub<u64> for &BigUint

Source

impl Sub<u64> for candid::types::number::Int

Source

impl Sub<u64> for candid::types::number::Nat

Source

impl Sub<u64> for BigInt

Source

impl Sub<u64> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<u128> for &u128

Source

impl Sub<u128> for &BigInt

Source

impl Sub<u128> for &BigUint

Source

impl Sub<u128> for candid::types::number::Int

Source

impl Sub<u128> for candid::types::number::Nat

Source

impl Sub<u128> for BigInt

Source

impl Sub<u128> for BigUint

1.0.0 (const: unstable) · Source

impl Sub<usize> for &usize

Source

impl Sub<usize> for &BigInt

Source

impl Sub<usize> for &BigUint

Source

impl Sub<usize> for candid::types::number::Int

Source

impl Sub<usize> for candid::types::number::Nat

Source

impl Sub<usize> for BigInt

Source

impl Sub<usize> for BigUint

Source

impl Sub<Duration> for Timestamp

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i8>> for &Saturating<i8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i16>> for &Saturating<i16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i32>> for &Saturating<i32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i64>> for &Saturating<i64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<i128>> for &Saturating<i128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<isize>> for &Saturating<isize>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u8>> for &Saturating<u8>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u16>> for &Saturating<u16>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u32>> for &Saturating<u32>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u64>> for &Saturating<u64>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<u128>> for &Saturating<u128>

1.74.0 (const: unstable) · Source

impl Sub<Saturating<usize>> for &Saturating<usize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i8>> for &Wrapping<i8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i16>> for &Wrapping<i16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i32>> for &Wrapping<i32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i64>> for &Wrapping<i64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<i128>> for &Wrapping<i128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<isize>> for &Wrapping<isize>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u8>> for &Wrapping<u8>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u16>> for &Wrapping<u16>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u32>> for &Wrapping<u32>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u64>> for &Wrapping<u64>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<u128>> for &Wrapping<u128>

1.14.0 (const: unstable) · Source

impl Sub<Wrapping<usize>> for &Wrapping<usize>

1.8.0 · Source

impl Sub<Duration> for Instant

1.8.0 · Source

impl Sub<Duration> for SystemTime

Source

impl Sub<Duration> for time::date::Date

Source

impl Sub<Duration> for time::duration::Duration

Source

impl Sub<Duration> for OffsetDateTime

Source

impl Sub<Duration> for PrimitiveDateTime

Source

impl Sub<Duration> for Time

Source

impl Sub<Duration> for UtcDateTime

Source

impl Sub<SystemTime> for OffsetDateTime

Source

impl Sub<SystemTime> for UtcDateTime

Source

impl Sub<Int> for i8

Source

impl Sub<Int> for i16

Source

impl Sub<Int> for i32

Source

impl Sub<Int> for i64

Source

impl Sub<Int> for i128

Source

impl Sub<Int> for isize

Source

impl Sub<Int> for u8

Source

impl Sub<Int> for u16

Source

impl Sub<Int> for u32

Source

impl Sub<Int> for u64

Source

impl Sub<Int> for u128

Source

impl Sub<Int> for usize

Source

impl Sub<Nat> for u8

Source

impl Sub<Nat> for u16

Source

impl Sub<Nat> for u32

Source

impl Sub<Nat> for u64

Source

impl Sub<Nat> for u128

Source

impl Sub<Nat> for usize

Source

impl Sub<bf16> for &bf16

Source

impl Sub<f16> for &f16

Source

impl Sub<BigInt> for &i8

Source

impl Sub<BigInt> for &i16

Source

impl Sub<BigInt> for &i32

Source

impl Sub<BigInt> for &i64

Source

impl Sub<BigInt> for &i128

Source

impl Sub<BigInt> for &isize

Source

impl Sub<BigInt> for &u8

Source

impl Sub<BigInt> for &u16

Source

impl Sub<BigInt> for &u32

Source

impl Sub<BigInt> for &u64

Source

impl Sub<BigInt> for &u128

Source

impl Sub<BigInt> for &usize

Source

impl Sub<BigInt> for &BigInt

Source

impl Sub<BigInt> for i8

Source

impl Sub<BigInt> for i16

Source

impl Sub<BigInt> for i32

Source

impl Sub<BigInt> for i64

Source

impl Sub<BigInt> for i128

Source

impl Sub<BigInt> for isize

Source

impl Sub<BigInt> for u8

Source

impl Sub<BigInt> for u16

Source

impl Sub<BigInt> for u32

Source

impl Sub<BigInt> for u64

Source

impl Sub<BigInt> for u128

Source

impl Sub<BigInt> for usize

Source

impl Sub<BigUint> for &u8

Source

impl Sub<BigUint> for &u16

Source

impl Sub<BigUint> for &u32

Source

impl Sub<BigUint> for &u64

Source

impl Sub<BigUint> for &u128

Source

impl Sub<BigUint> for &usize

Source

impl Sub<BigUint> for &BigUint

Source

impl Sub<BigUint> for u8

Source

impl Sub<BigUint> for u16

Source

impl Sub<BigUint> for u32

Source

impl Sub<BigUint> for u64

Source

impl Sub<BigUint> for u128

Source

impl Sub<BigUint> for usize

Source

impl Sub<Duration> for core::time::Duration

Source

impl Sub<Duration> for Instant

Source

impl Sub<Duration> for SystemTime

Available on crate feature std only.
Source

impl Sub<Duration> for time::date::Date

Source

impl Sub<Duration> for OffsetDateTime

Source

impl Sub<Duration> for PrimitiveDateTime

Source

impl Sub<Duration> for Time

Source

impl Sub<Duration> for UtcDateTime

Source

impl Sub<OffsetDateTime> for SystemTime

Source

impl Sub<OffsetDateTime> for UtcDateTime

Source

impl Sub<UtcDateTime> for SystemTime

Source

impl Sub<UtcDateTime> for OffsetDateTime

Source

impl Sub<B0> for UTerm

UTerm - B0 = Term

Source

impl Sub<B1> for UInt<UTerm, B1>

UInt<UTerm, B1> - B1 = UTerm

Source

impl<'lhs, 'rhs, T, const N: usize> Sub<&'rhs Simd<T, N>> for &'lhs Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<O> Sub for F32<O>
where O: ByteOrder,

Source

impl<O> Sub for F64<O>
where O: ByteOrder,

Source

impl<O> Sub for I16<O>
where O: ByteOrder,

Source

impl<O> Sub for I32<O>
where O: ByteOrder,

Source

impl<O> Sub for I64<O>
where O: ByteOrder,

Source

impl<O> Sub for I128<O>
where O: ByteOrder,

Source

impl<O> Sub for Isize<O>
where O: ByteOrder,

Source

impl<O> Sub for U16<O>
where O: ByteOrder,

Source

impl<O> Sub for U32<O>
where O: ByteOrder,

Source

impl<O> Sub for U64<O>
where O: ByteOrder,

Source

impl<O> Sub for U128<O>
where O: ByteOrder,

Source

impl<O> Sub for Usize<O>
where O: ByteOrder,

Source

impl<O> Sub<f32> for F32<O>
where O: ByteOrder,

Source

impl<O> Sub<f64> for F64<O>
where O: ByteOrder,

Source

impl<O> Sub<i16> for I16<O>
where O: ByteOrder,

Source

impl<O> Sub<i32> for I32<O>
where O: ByteOrder,

Source

impl<O> Sub<i64> for I64<O>
where O: ByteOrder,

Source

impl<O> Sub<i128> for I128<O>
where O: ByteOrder,

Source

impl<O> Sub<isize> for Isize<O>
where O: ByteOrder,

Source

impl<O> Sub<u16> for U16<O>
where O: ByteOrder,

Source

impl<O> Sub<u32> for U32<O>
where O: ByteOrder,

Source

impl<O> Sub<u64> for U64<O>
where O: ByteOrder,

Source

impl<O> Sub<u128> for U128<O>
where O: ByteOrder,

Source

impl<O> Sub<usize> for Usize<O>
where O: ByteOrder,

Source

impl<O> Sub<F32<O>> for f32
where O: ByteOrder,

Source

impl<O> Sub<F64<O>> for f64
where O: ByteOrder,

Source

impl<O> Sub<I16<O>> for i16
where O: ByteOrder,

Source

impl<O> Sub<I32<O>> for i32
where O: ByteOrder,

Source

impl<O> Sub<I64<O>> for i64
where O: ByteOrder,

Source

impl<O> Sub<I128<O>> for i128
where O: ByteOrder,

Source

impl<O> Sub<Isize<O>> for isize
where O: ByteOrder,

Source

impl<O> Sub<U16<O>> for u16
where O: ByteOrder,

Source

impl<O> Sub<U32<O>> for u32
where O: ByteOrder,

Source

impl<O> Sub<U64<O>> for u64
where O: ByteOrder,

Source

impl<O> Sub<U128<O>> for u128
where O: ByteOrder,

Source

impl<O> Sub<Usize<O>> for usize
where O: ByteOrder,

1.0.0 · Source

impl<T, A> Sub<&BTreeSet<T, A>> for &BTreeSet<T, A>
where T: Ord + Clone, A: Allocator + Clone,

1.0.0 · Source

impl<T, S> Sub<&HashSet<T, S>> for &HashSet<T, S>
where T: Eq + Hash + Clone, S: BuildHasher + Default,

Source

type Output = HashSet<T, S>

Source

impl<T, const N: usize> Sub<&Simd<T, N>> for Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<T, const N: usize> Sub<Simd<T, N>> for &Simd<T, N>
where T: SimdElement, Simd<T, N>: Sub<Output = Simd<T, N>>,

Source

type Output = Simd<T, N>

Source

impl<U> Sub<B1> for UInt<U, B0>
where U: Unsigned + Sub<B1>, <U as Sub<B1>>::Output: Unsigned,

UInt<U, B0> - B1 = UInt<U - B1, B1>

Source

type Output = UInt<<U as Sub<B1>>::Output, B1>

Source

impl<U> Sub<NInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - N = P

Source

impl<U> Sub<PInt<U>> for Z0
where U: Unsigned + NonZero,

Z0 - P = N

Source

impl<U> Sub<Z0> for NInt<U>
where U: Unsigned + NonZero,

NInt - Z0 = NInt

Source

impl<U> Sub<Z0> for PInt<U>
where U: Unsigned + NonZero,

PInt - Z0 = PInt

Source

impl<U, B> Sub<B0> for UInt<U, B>
where U: Unsigned, B: Bit,

UInt - B0 = UInt

Source

type Output = UInt<U, B>

Source

impl<U, B> Sub<B1> for UInt<UInt<U, B>, B1>
where U: Unsigned, B: Bit,

UInt<U, B1> - B1 = UInt<U, B0>

Source

type Output = UInt<UInt<U, B>, B0>

Source

impl<Ul, Bl, Ur> Sub<Ur> for UInt<Ul, Bl>
where Ul: Unsigned, Bl: Bit, Ur: Unsigned, UInt<Ul, Bl>: PrivateSub<Ur>, <UInt<Ul, Bl> as PrivateSub<Ur>>::Output: Trim,

Subtracting unsigned integers. We just do our PrivateSub and then Trim the output.

Source

type Output = <<UInt<Ul, Bl> as PrivateSub<Ur>>::Output as Trim>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero, Ur: Unsigned + NonZero + Cmp<Ul> + PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>,

N(Ul) - N(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ur as PrivateIntegerAdd<<Ur as Cmp<Ul>>::Output, Ul>>::Output

Source

impl<Ul, Ur> Sub<NInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

P(Ul) - N(Ur) = P(Ul + Ur)

Source

type Output = PInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for NInt<Ul>
where Ul: Unsigned + NonZero + Add<Ur>, Ur: Unsigned + NonZero, <Ul as Add<Ur>>::Output: Unsigned + NonZero,

N(Ul) - P(Ur) = N(Ul + Ur)

Source

type Output = NInt<<Ul as Add<Ur>>::Output>

Source

impl<Ul, Ur> Sub<PInt<Ur>> for PInt<Ul>
where Ul: Unsigned + NonZero + Cmp<Ur> + PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>, Ur: Unsigned + NonZero,

P(Ul) - P(Ur): We resolve this with our PrivateAdd

Source

type Output = <Ul as PrivateIntegerAdd<<Ul as Cmp<Ur>>::Output, Ur>>::Output

Source

impl<Vl, Al, Vr, Ar> Sub<TArr<Vr, Ar>> for TArr<Vl, Al>
where Vl: Sub<Vr>, Al: Sub<Ar>,

Source

type Output = TArr<<Vl as Sub<Vr>>::Output, <Al as Sub<Ar>>::Output>

Source

impl<const N: usize> Sub for Simd<f16, N>

Source

impl<const N: usize> Sub for Simd<f32, N>

Source

impl<const N: usize> Sub for Simd<f64, N>

Source

impl<const N: usize> Sub for Simd<i8, N>
where i8: SimdElement,

Source

impl<const N: usize> Sub for Simd<i16, N>

Source

impl<const N: usize> Sub for Simd<i32, N>

Source

impl<const N: usize> Sub for Simd<i64, N>

Source

impl<const N: usize> Sub for Simd<isize, N>

Source

impl<const N: usize> Sub for Simd<u8, N>
where u8: SimdElement,

Source

impl<const N: usize> Sub for Simd<u16, N>

Source

impl<const N: usize> Sub for Simd<u32, N>

Source

impl<const N: usize> Sub for Simd<u64, N>

Source

impl<const N: usize> Sub for Simd<usize, N>