pub trait RuntimeValueDecode {
// Required method
fn from_value(value: &Value) -> Option<Self>
where Self: Sized;
}Expand description
Runtime-only reconstruction of a typed value from the canonical Value
union.
This contract must not be used as a persisted-row or primary-key codec.
Required Methods
Sourcefn from_value(value: &Value) -> Option<Self>where
Self: Sized,
fn from_value(value: &Value) -> Option<Self>where
Self: Sized,
Reconstruct a typed value when the runtime representation matches.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".