pub trait RuntimeValueEncode {
// Required method
fn to_value(&self) -> Value;
}Expand description
Runtime-only lowering from a typed value into the canonical Value union.
This contract must not be used as a persisted-row or primary-key codec.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".